package ext {

[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.Base")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.Mixin")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Native("Ext.Img", require)]
/**
 * Simple helper class for easily creating image components. This renders an image tag to
 * the DOM with the configured src.
 * <p>{&#64;img Ext.Img/Ext.Img.png Ext.Img component}</p>
 * <p><b><i>Example usage:</i></b></p>
 * <pre>
 * var changingImage = Ext.create('Ext.Img', {
 *     src: 'http://www.sencha.com/img/20110215-feat-html5.png',
 *     width: 184,
 *     height: 90,
 *     renderTo: Ext.getBody()
 * });
 *
 * // change the src of the image programmatically
 * changingImage.setSrc('http://www.sencha.com/img/20110215-feat-perf.png');
 * </pre>
 * <p>By default, only an img element is rendered and that is this component's primary
 * <code>element</code>. If the <code>ext.Component#autoEl</code> property
 * is other than 'img' (the default), the a child img element will be added to the primary
 * element. This can be used to create a wrapper element around the img.</p>
 * <p><b><i>Wrapping the img in a div:</i></b></p>
 * <pre>
 * var wrappedImage = Ext.create('Ext.Img', {
 *     src: 'http://www.sencha.com/img/20110215-feat-html5.png',
 *     autoEl: 'div', // wrap in a div
 *     renderTo: Ext.getBody()
 * });
 * </pre>
 * <p><b><i>Using a glyph</i></b></p>
 * <pre>
 * var glyphImage = Ext.create('Ext.Img', {
 *     glyph: 'xf015&#64;FontAwesome',     // the "home" icon
 *     renderTo: Ext.getBody()
 * });
 * </pre>
 * <p><b><i>Image Dimensions</i></b></p>
 * <p>You should include height and width dimensions for any image owned by a parent
 * container. By omitting dimensions, an owning container will not know how to
 * size and position the image in the initial layout.</p>
 * @see ext.Component#getEl()
 * @see ext.Component#autoEl
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Img.html Original Ext JS documentation of 'Ext.Img'
 */
public class Img extends ext.Component {
  /**
   * @param config @inheritDoc
   */
  public function Img(config:ext.Img = null) {
    super();
  }

  [ExtConfig]
  /**
   * The descriptive text for non-visual UI description.
   * @default ''
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Img.html#cfg-alt Original Ext JS documentation of 'alt'
   * @see #setAlt()
   */
  public native function get alt():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set alt(value:String):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * A numeric unicode character code to use as the icon. The default font-family
   * for glyphs can be set globally using
   * <code>glyphFontFamily</code> application
   * config or the <i>Ext.setGlyphFontFamily()</i> method.
   * It is initially set to <code>'Pictos'</code>.
   * <p>The following shows how to set the glyph using the font icons provided in the
   * SDK (assuming the font-family has been configured globally):</p>
   * <pre>
   * // assumes the glyphFontFamily is "Pictos"
   * glyph: 'x48'       // the "home" icon (H character)
   *
   * // assumes the glyphFontFamily is "Pictos"
   * glyph: 72          // The "home" icon (H character)
   *
   * // assumes the glyphFontFamily is "Pictos"
   * glyph: 'H'         // the "home" icon
   * </pre>
   * <p>Alternatively, this config option accepts a string with the charCode and
   * font-family separated by the <code>&#64;</code> symbol.</p>
   * <pre>
   * // using Font Awesome
   * glyph: 'xf015&#64;FontAwesome'     // the "home" icon
   *
   * // using Pictos
   * glyph: 'H&#64;Pictos'              // the "home" icon
   * </pre>
   * <p>Depending on the theme you're using, you may need include the font icon
   * packages in your application in order to use the icons included in the
   * SDK. For more information see:</p>
   * <ul>
   * <li><a href="http://fortawesome.github.io/Font-Awesome/cheatsheet/">Font Awesome icons</a></li>
   * <li><a href="../guides/core_concepts/font_ext.html">Pictos icons</a></li>
   * <li><a href="../guides/core_concepts/theming.html">Theming Guide</a></li>
   * </ul>
   * @see ext.app.Application#glyphFontFamily
   * @see ext.SExt#setGlyphFontFamily() Ext.setGlyphFontFamily()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Img.html#cfg-glyph Original Ext JS documentation of 'glyph'
   * @see #getGlyph()
   * @see #setGlyph()
   */
  public native function get glyph():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set glyph(value:*):void;

  [ExtConfig]
  /**
   * Optional CSS classes to add to the img element.
   * @default ''
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Img.html#cfg-imgCls Original Ext JS documentation of 'imgCls'
   */
  public native function get imgCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set imgCls(value:String):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The source of this image. See <code>ext.SExt#resolveResource()</code> for
   * details on locating application resources.
   * @see ext.SExt#resolveResource()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Img.html#cfg-src Original Ext JS documentation of 'src'
   * @see #getSrc()
   * @see #setSrc()
   */
  public native function get src():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set src(value:String):void;

  [ExtConfig]
  /**
   * Specifies addtional information about the image.
   * @default ''
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Img.html#cfg-title Original Ext JS documentation of 'title'
   * @see #setTitle()
   */
  public native function get title():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set title(value:String):void;

  /**
   * Returns the value of <code>glyph</code>.
   * @see #glyph
   */
  public native function getGlyph():*;

  /**
   * Returns the size of the image as an object.
   * @since 6.2.0
   * @return The size and aspect ratio of the image.
   * <ul>
   * <li><code>aspect</code> : Number (optional)
   * The aspect ration of the image (<code>width / height</code>).
   * </li>
   * <li><code>height</code> : Number (optional)
   * The height of the image.
   * </li>
   * <li><code>width</code> : Number (optional)
   * The width of the image.
   * </li>
   * </ul>
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Img.html#method-getNaturalSize Original Ext JS documentation of 'getNaturalSize'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Img.html#property-aspect Original Ext JS documentation of 'aspect'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Img.html#property-height Original Ext JS documentation of 'height'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Img.html#property-width Original Ext JS documentation of 'width'
   */
  public native function getNaturalSize():Object;

  /**
   * Returns the value of <code>src</code>.
   * @see #src
   */
  public native function getSrc():String;

  /**
   * Updates the <code>alt</code> of the image.
   * @see #alt
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Img.html#method-setAlt Original Ext JS documentation of 'setAlt'
   */
  public native function setAlt(alt:String):void;

  /**
   * Sets the value of <code>glyph</code>.
   * @param glyph The new value.
   * @see #glyph
   */
  public native function setGlyph(glyph:*):void;

  /**
   * Sets the value of <code>src</code>.
   * @param src The new value.
   * @see #src
   */
  public native function setSrc(src:String):void;

  /**
   * Updates the <code>title</code> of the image.
   * @see #title
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Img.html#method-setTitle Original Ext JS documentation of 'setTitle'
   */
  public native function setTitle(title:String):void;
}
}