package ext.container {
import ext.mixin.IResponsive;

[Uses("ext.container.Container")]
[Uses("ext.mixin.Responsive")]
[Uses("ext.Mixin")]
[Uses("ext.Base")]
[Uses("ext.mixin.Queryable")]
[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Uses("ext.mixin.Container")]
[Native("Ext.container.Viewport", require)]
/**
 * A specialized container representing the viewable application area (the browser viewport).
 * <p>The Viewport renders itself to the document body, and automatically sizes itself to the size of
 * the browser viewport and manages window resizing. There may only be one Viewport created
 * in a page.</p>
 * <p>Like any <code>ext.container.Container</code>, a Viewport will only perform sizing and positioning
 * on its child Components if you configure it with a <code>layout</code>.</p>
 * <p>A Common layout used with Viewports is <code>ext.layout.container.BorderLayout</code>, but if the
 * required layout is simpler, a different layout should be chosen.</p>
 * <p>For example, to simply make a single child item occupy all available space, use
 * <code>ext.layout.container.FitLayout</code>.</p>
 * <p>To display one "active" item at full size from a choice of several child items, use
 * <code>ext.layout.container.CardLayout</code>.</p>
 * <p>Inner layouts are available because all <code>ext.panel.Panel</code>s
 * added to the Viewport, either through its <code>items</code>, or the <code>add()</code>
 * method of any of its child Panels may themselves have a layout.</p>
 * <p>The Viewport does not provide scrolling, so child Panels within the Viewport should provide
 * for scrolling if needed using the <code>scrollable</code> config.</p>
 * <p>An example showing a classic application border layout:</p>
 * <p><b>Example:</b></p>
 * <pre>
 * Ext.create('Ext.container.Viewport', {
 *     layout: 'border',
 *     items: [{
 *         region: 'north',
 *         html: '&lt;h1 class="x-panel-header"&gt;Page Title&lt;/h1&gt;',
 *         border: false,
 *         margin: '0 0 5 0'
 *     }, {
 *         region: 'west',
 *         collapsible: true,
 *         title: 'Navigation',
 *         width: 150
 *         // could use a TreePanel or AccordionLayout for navigational items
 *     }, {
 *         region: 'south',
 *         title: 'South Panel',
 *         collapsible: true,
 *         html: 'Information goes here',
 *         split: true,
 *         height: 100,
 *         minHeight: 100
 *     }, {
 *         region: 'east',
 *         title: 'East Panel',
 *         collapsible: true,
 *         split: true,
 *         width: 150
 *     }, {
 *         region: 'center',
 *         xtype: 'tabpanel', // TabPanel itself has no title
 *         activeTab: 0,      // First tab active by default
 *         items: {
 *             title: 'Default Tab',
 *             html: 'The first tab\'s content. Others may be added dynamically'
 *         }
 *     }]
 * });
 * </pre>
 * <p>Alternatively you can turn any normal Container (or Component) into a Viewport using
 * the <code>ext.plugin.ViewportPlugin</code>.</p>
 * @see ext.container.Container
 * @see #layout
 * @see ext.layout.container.BorderLayout
 * @see ext.layout.container.FitLayout
 * @see ext.layout.container.CardLayout
 * @see ext.panel.Panel
 * @see #items
 * @see #add()
 * @see #scrollable
 * @see ext.plugin.ViewportPlugin
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.container.Viewport.html Original Ext JS documentation of 'Ext.container.Viewport'
 */
public class Viewport extends ext.container.Container implements ext.mixin.IResponsive {
  /**
   * @param config @inheritDoc
   */
  public function Viewport(config:ext.container.Viewport = null) {
    super();
  }

  /**
   * <code>true</code> in this class to identify an object as an instantiated Viewport, or subclass thereof.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.container.Viewport.html#property-isViewport Original Ext JS documentation of 'isViewport'
   */
  public native function get isViewport():Boolean;

  [ExtConfig]
  /**
   * The maximum zoom scale. Only applicable for touch devices. Set this to 1 to
   * disable zooming.
   * @default 10
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.container.Viewport.html#cfg-maxUserScale Original Ext JS documentation of 'maxUserScale'
   */
  public native function get maxUserScale():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set maxUserScale(value:Number):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * This object consists of keys that represent the conditions on which configs
   * will be applied. For example:
   * <pre>
   *  responsiveConfig: {
   *      landscape: {
   *          region: 'west'
   *      },
   *      portrait: {
   *          region: 'north'
   *      }
   *  }
   * </pre>
   * <p>In this case the keys ("landscape" and "portrait") are the criteria (or "rules")
   * and the object to their right contains the configs that will apply when that
   * rule is true.</p>
   * <p>These rules can be any valid JavaScript expression but the following values
   * are considered in scope:</p>
   * <ul>
   * <li><code>landscape</code> - True if the device orientation is landscape (always <code>true</code> on
   * desktop devices).</li>
   * <li><code>portrait</code> - True if the device orientation is portrait (always <code>false</code> on
   * desktop devices).</li>
   * <li><code>tall</code> - True if <code>width</code> &lt; <code>height</code> regardless of device type.</li>
   * <li><code>wide</code> - True if <code>width</code> &gt; <code>height</code> regardless of device type.</li>
   * <li><code>width</code> - The width of the viewport in pixels.</li>
   * <li><code>height</code> - The height of the viewport in pixels.</li>
   * <li><code>platform</code> - An object containing various booleans describing the platform
   * (see <code>Ext.platformTags</code>). The properties of this
   * object are also available implicitly (without "platform." prefix) but this
   * sub-object may be useful to resolve ambiguity (for example, if one of the
   * <code>responsiveFormulas</code> overlaps and hides any of these properties).
   * Previous to Ext JS 5.1, the <code>platformTags</code> were only available using this
   * prefix.</li>
   * </ul>
   * <p>A more complex example:</p>
   * <pre>
   *  responsiveConfig: {
   *      'desktop || width &gt; 800': {
   *          region: 'west'
   *      },
   *
   *      '!(desktop || width &gt; 800)': {
   *          region: 'north'
   *      }
   *  }
   * </pre>
   * <p><b>NOTE</b>: If multiple rules set a single config (like above), it is important
   * that the rules be mutually exclusive. That is, only one rule should set each
   * config. If multiple rules are actively setting a single config, the order of
   * these (and therefore the config's value) is unspecified.</p>
   * <p>For a config to participate as a <code>responsiveConfig</code> it must have a "setter"
   * method. In the above example, a "setRegion" method must exist.</p>
   * @since 5.0.0
   * @see ext.SExt#platformTags
   * @see #responsiveFormulas
   * @see #responsiveConfig
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Responsive.html#cfg-responsiveConfig Original Ext JS documentation of 'responsiveConfig'
   * @see #getResponsiveConfig()
   * @see #setResponsiveConfig()
   */
  public native function get responsiveConfig():Object;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set responsiveConfig(value:Object):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * It is common when using <code>responsiveConfig</code> to have recurring expressions that
   * make for complex configurations. Using <code>responsiveFormulas</code> allows you to cut
   * down on this repetition by adding new properties to the "scope" for the rules
   * in a <code>responsiveConfig</code>.
   * <p>For example:</p>
   * <pre>
   *  Ext.define('MyApp.view.main.Main', {
   *      extend: 'Ext.container.Container',
   *
   *      mixins: [
   *          'Ext.mixin.Responsive'
   *      ],
   *
   *      responsiveFormulas: {
   *          small: 'width &lt; 600',
   *
   *          medium: 'width &gt;= 600 &amp;&amp; width &lt; 800',
   *
   *          large: 'width &gt;= 800',
   *
   *          tuesday: function (context) {
   *              return (new Date()).getDay() === 2;
   *          }
   *      }
   *  });
   * </pre>
   * <p>With the above declaration, any <code>responsiveConfig</code> can now use these values
   * like so:</p>
   * <pre>
   *  responsiveConfig: {
   *      small: {
   *          hidden: true
   *      },
   *      'medium &amp;&amp; !tuesday': {
   *          hidden: false,
   *          region: 'north'
   *      },
   *      large: {
   *          hidden: false,
   *          region: 'west'
   *      }
   *  }
   * </pre>
   * @default 0
   * @since 5.0.1
   * @see #responsiveConfig
   * @see #responsiveFormulas
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Responsive.html#cfg-responsiveFormulas Original Ext JS documentation of 'responsiveFormulas'
   * @see #getResponsiveFormulas()
   * @see #setResponsiveFormulas()
   */
  public native function get responsiveFormulas():Object;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set responsiveFormulas(value:Object):void;

  /**
   * Returns the value of <code>responsiveConfig</code>.
   * @see #responsiveConfig
   */
  public native function getResponsiveConfig():Object;

  /**
   * Returns the value of <code>responsiveFormulas</code>.
   * @see #responsiveFormulas
   */
  public native function getResponsiveFormulas():Object;

  /**
   * Sets the value of <code>responsiveConfig</code>.
   * @param responsiveConfig The new value.
   * @see #responsiveConfig
   */
  public native function setResponsiveConfig(responsiveConfig:Object):void;

  /**
   * Sets the value of <code>responsiveFormulas</code>.
   * @param responsiveFormulas The new value.
   * @see #responsiveFormulas
   */
  public native function setResponsiveFormulas(responsiveFormulas:Object):void;
}
}