package ext.form {
import ext.Component;
import ext.container.Container;
import ext.form.field.Checkbox;
import ext.form.field.Field;
import ext.panel.Tool;

[Uses("ext.container.Container")]
[Uses("ext.form.FieldAncestor")]
[Uses("ext.Mixin")]
[Uses("ext.Base")]
[Uses("ext.mixin.Queryable")]
[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Uses("ext.mixin.Container")]
[Native("Ext.form.FieldSet", require)]
/**
 * @see ext.form.events.FieldSet_field_errorEvent.FIELD_ERROR_CHANGE
 * @eventType ext.form.events.FieldSet_field_errorEvent.FIELD_ERROR_CHANGE
 */
[Event(name = 'onFieldErrorChange', type = 'ext.form.events.FieldSet_field_errorEvent')]
/**
 * @see ext.form.events.FieldSet_field_isValidEvent.FIELD_VALIDITY_CHANGE
 * @eventType ext.form.events.FieldSet_field_isValidEvent.FIELD_VALIDITY_CHANGE
 */
[Event(name = 'onFieldValidityChange', type = 'ext.form.events.FieldSet_field_isValidEvent')]
/**
 * @see ext.form.events.FieldSetEvent.BEFORE_COLLAPSE
 * @eventType ext.form.events.FieldSetEvent.BEFORE_COLLAPSE
 */
[Event(name = 'onBeforeCollapse', type = 'ext.form.events.FieldSetEvent')]
/**
 * @see ext.form.events.FieldSetEvent.BEFORE_EXPAND
 * @eventType ext.form.events.FieldSetEvent.BEFORE_EXPAND
 */
[Event(name = 'onBeforeExpand', type = 'ext.form.events.FieldSetEvent')]
/**
 * @see ext.form.events.FieldSetEvent.COLLAPSE
 * @eventType ext.form.events.FieldSetEvent.COLLAPSE
 */
[Event(name = 'onCollapse', type = 'ext.form.events.FieldSetEvent')]
/**
 * @see ext.form.events.FieldSetEvent.EXPAND
 * @eventType ext.form.events.FieldSetEvent.EXPAND
 */
[Event(name = 'onExpand', type = 'ext.form.events.FieldSetEvent')]
/**
 * A container for grouping sets of fields, rendered as a HTML <code>fieldset</code> element. The <code>title</code>
 * config will be rendered as the fieldset's <code>legend</code>.
 * <p>While FieldSets commonly contain simple groups of fields, they are general <code>ext.container.Container</code>
 * and may therefore contain any type of components in their <code>items</code>, including other nested containers.
 * The default <code>layout</code> for the FieldSet's items is <code>'anchor'</code>, but it can be configured to use any other
 * layout type.</p>
 * <p>FieldSets may also be collapsed if configured to do so; this can be done in two ways:</p>
 * <ol>
 * <li>Set the <code>collapsible</code> config to true; this will result in a collapse button being rendered next to
 * the <i>legend title</i>, or:</li>
 * <li>Set the <code>checkboxToggle</code> config to true; this is similar to using <code>collapsible</code> but renders
 * a <code>ext.form.field.Checkbox</code> in place of the toggle button. The fieldset will be expanded when the
 * checkbox is checked and collapsed when it is unchecked. The checkbox will also be included in the
 * <i>form submit parameters</i> using <code>checkbox</code>.</li>
 * </ol>
 * <p><b>Example usage</b></p>
 * <p><b>Example:</b></p>
 * <pre>
 * Ext.create('Ext.form.Panel', {
 *     title: 'Simple Form with FieldSets',
 *     labelWidth: 75, // label settings here cascade unless overridden
 *     url: 'save-form.php',
 *     frame: true,
 *     bodyStyle: 'padding:5px 5px 0',
 *     width: 550,
 *     renderTo: Ext.getBody(),
 *     layout: 'column', // arrange fieldsets side by side
 *     items: [{
 *         // Fieldset in Column 1 - collapsible via toggle button
 *         xtype:'fieldset',
 *         columnWidth: 0.5,
 *         title: 'Fieldset 1',
 *         collapsible: true,
 *         defaultType: 'textfield',
 *         defaults: {anchor: '100%'},
 *         layout: 'anchor',
 *         items :[{
 *             fieldLabel: 'Field 1',
 *             name: 'field1'
 *         }, {
 *             fieldLabel: 'Field 2',
 *             name: 'field2'
 *         }]
 *     }, {
 *         // Fieldset in Column 2 - collapsible via checkbox, collapsed by default, contains a panel
 *         xtype:'fieldset',
 *         title: 'Show Panel', // title or checkboxToggle creates fieldset header
 *         columnWidth: 0.5,
 *         checkboxToggle: true,
 *         collapsed: true, // fieldset initially collapsed
 *         layout:'anchor',
 *         items :[{
 *             xtype: 'panel',
 *             anchor: '100%',
 *             title: 'Panel inside a fieldset',
 *             frame: true,
 *             height: 52
 *         }]
 *     }]
 * });
 * </pre>
 * @see #title
 * @see #legend
 * @see ext.container.Container
 * @see #items
 * @see #layout
 * @see #collapsible
 * @see #title legend title
 * @see #checkboxToggle
 * @see ext.form.field.Checkbox
 * @see ext.form.BasicForm#submit() form submit parameters
 * @see #checkbox
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html Original Ext JS documentation of 'Ext.form.FieldSet'
 */
public class FieldSet extends ext.container.Container implements ext.form.IFieldAncestor {
  /**
   * @param config @inheritDoc
   */
  public function FieldSet(config:ext.form.FieldSet = null) {
    super();
  }

  [ExtConfig]
  /**
   * The base CSS class applied to the fieldset.
   * @default 'x-fieldset'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#cfg-baseCls Original Ext JS documentation of 'baseCls'
   */
  override public native function get baseCls():String;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set baseCls(value:String):void;

  [ExtConfig]
  /**
   * A configuration for the generated checkbox that is adjacent to the <code>title</code> in the header.
   * This config is only effective when <code>checkboxToggle</code> is true
   * @since 6.2.0
   * @see #title
   * @see #checkboxToggle
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#cfg-checkbox Original Ext JS documentation of 'checkbox'
   */
  public native function get checkbox():Object;

  [ExtConfig]
  /**
   * @private
   */
  public native function set checkbox(value:Object):void;

  /**
   * Refers to the <code>ext.form.field.Checkbox</code> component that is added next to the title in the legend. Only
   * populated if the fieldset is configured with <code>checkboxToggle</code>:true.
   * @see ext.form.field.Checkbox
   * @see #checkboxToggle
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#property-checkboxCmp Original Ext JS documentation of 'checkboxCmp'
   */
  public native function get checkboxCmp():ext.form.field.Checkbox;

  /**
   * @private
   */
  public native function set checkboxCmp(value:ext.form.field.Checkbox):void;

  [Deprecated(replacement = "checkbox", since = "6.2.0")]
  [ExtConfig]
  /**
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#cfg-checkboxName Original Ext JS documentation of 'checkboxName'
   */
  public native function get checkboxName():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set checkboxName(value:String):void;

  [ExtConfig]
  /**
   * Set to true to render a checkbox into the fieldset frame just in front of the legend to expand/collapse the
   * fieldset when the checkbox is toggled.. This checkbox will be included in form submits using
   * the <code>checkbox</code> configuration.
   * @default false
   * @see #checkbox
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#cfg-checkboxToggle Original Ext JS documentation of 'checkboxToggle'
   */
  public native function get checkboxToggle():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set checkboxToggle(value:Boolean):void;

  [ExtConfig]
  /**
   * The ui to use for the fieldset's checkbox.
   * @default 'default'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#cfg-checkboxUI Original Ext JS documentation of 'checkboxUI'
   */
  public native function get checkboxUI():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set checkboxUI(value:String):void;

  [ExtConfig]
  /**
   * Set to true to render the fieldset as collapsed by default. If <code>checkboxToggle</code> is specified, the checkbox
   * will also be unchecked by default.
   * @default false
   * @see #checkboxToggle
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#cfg-collapsed Original Ext JS documentation of 'collapsed'
   * @see #setCollapsed()
   */
  public native function get collapsed():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set collapsed(value:Boolean):void;

  [ExtConfig]
  /**
   * Set to true to make the fieldset collapsible and have the expand/collapse toggle button automatically rendered
   * into the legend element, false to keep the fieldset statically sized with no collapse button.
   * Another option is to configure <code>checkboxToggle</code>. Use the <code>collapsed</code> config to collapse the
   * fieldset by default.
   * @default false
   * @see #checkboxToggle
   * @see #collapsed
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#cfg-collapsible Original Ext JS documentation of 'collapsible'
   */
  public native function get collapsible():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set collapsible(value:Boolean):void;

  [ExtConfig]
  /**
   * Fieldset description to be announced by screen readers.
   * @default '{0} field set'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#cfg-descriptionText Original Ext JS documentation of 'descriptionText'
   */
  public native function get descriptionText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set descriptionText(value:String):void;

  [ExtConfig]
  /**
   * Text to be announced by screen readers when toggle tool
   * or checkbox is focused.
   * @default 'Expand field set'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#cfg-expandText Original Ext JS documentation of 'expandText'
   */
  public native function get expandText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set expandText(value:String):void;

  [ExtConfig]
  /**
   * If specified, the properties in this object are used as default config values for each <code>ext.form.Labelable</code>
   * instance (e.g. <code>ext.form.field.BaseField</code> or <code>ext.form.FieldContainer</code>) that is added as a descendant of
   * this container. Corresponding values specified in an individual field's own configuration, or from the <i>defaults config</i> of its parent container, will take precedence. See the
   * documentation for <code>ext.form.Labelable</code> to see what config options may be specified in the fieldDefaults.
   * <p>Example:</p>
   * <pre>
   * new Ext.form.Panel({
   *     fieldDefaults: {
   *         labelAlign: 'left',
   *         labelWidth: 100
   *     },
   *     items: [{
   *         xtype: 'fieldset',
   *         defaults: {
   *             labelAlign: 'top'
   *         },
   *         items: [{
   *             name: 'field1'
   *         }, {
   *             name: 'field2'
   *         }]
   *     }, {
   *         xtype: 'fieldset',
   *         items: [{
   *             name: 'field3',
   *             labelWidth: 150
   *         }, {
   *             name: 'field4'
   *         }]
   *     }]
   * });
   * </pre>
   * <p>In this example, field1 and field2 will get labelAlign:'top' (from the fieldset's defaults) and labelWidth:100
   * (from fieldDefaults), field3 and field4 will both get labelAlign:'left' (from fieldDefaults and field3 will use
   * the labelWidth:150 from its own config.</p>
   * @see ext.form.Labelable
   * @see ext.form.field.BaseField
   * @see ext.form.FieldContainer
   * @see ext.container.Container#defaults defaults config
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldAncestor.html#cfg-fieldDefaults Original Ext JS documentation of 'fieldDefaults'
   */
  public native function get fieldDefaults():Object;

  [ExtConfig]
  /**
   * @private
   */
  public native function set fieldDefaults(value:Object):void;

  [ExtConfig]
  /**
   * The <code>ext.container.Container#layout</code> for the fieldset's immediate child items.
   * @default 'anchor'
   * @see ext.container.Container#layout
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#cfg-layout Original Ext JS documentation of 'layout'
   * @see #setLayout()
   */
  override public native function get layout():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  override public native function set layout(value:*):void;

  /**
   * The component for the fieldset's legend. Will only be defined if the configuration requires a legend to be
   * created, by setting the <code>title</code> or <code>checkboxToggle</code> options.
   * @see #title
   * @see #checkboxToggle
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#property-legend Original Ext JS documentation of 'legend'
   */
  public native function get legend():ext.Component;

  /**
   * @private
   */
  public native function set legend(value:ext.Component):void;

  [ArrayElementType("String")]
  [ExtConfig]
  /**
   * An array of events that, when fired, should trigger this object to
   * save its state. <code>stateEvents</code> defaults to the <code>stateEvents</code> associated with the
   * component you are using. Any events you statically set will be appended to that list.
   * <code>stateEvents</code> may be any type of event supported by this object, including
   * browser or custom events (e.g., <code>['click', 'customerchange']</code>).
   * <p>See <code>stateful</code> for an explanation of saving and
   * restoring object state.
   * By default the following stateEvents are added:</p>
   * <ul>
   * <li><code>event:onResize</code> - <i>(added by Ext.Component)</i></li>
   * <li><code>event:onCollapse</code></li>
   * <li><code>event:onExpand</code></li>
   * </ul>
   * @default [
   *     'collapse',
   *     'expand'
   * ]
   * @see #stateEvents
   * @see #stateful
   * @see #event:onResize
   * @see #event:onCollapse
   * @see #event:onExpand
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#cfg-stateEvents Original Ext JS documentation of 'stateEvents'
   */
  override public native function get stateEvents():Array;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set stateEvents(value:Array):void;

  [ExtConfig]
  /**
   * A title to be displayed in the fieldset's legend. May contain HTML markup.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#cfg-title Original Ext JS documentation of 'title'
   * @see #setTitle()
   */
  public native function get title():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set title(value:String):void;

  /**
   * Refers to the <code>ext.panel.Tool</code> component that is added as the collapse/expand button next to the title in
   * the legend. Only populated if the fieldset is configured with <code>collapsible</code>:true.
   * @see ext.panel.Tool
   * @see #collapsible
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#property-toggleCmp Original Ext JS documentation of 'toggleCmp'
   */
  public native function get toggleCmp():ext.panel.Tool;

  /**
   * @private
   */
  public native function set toggleCmp(value:ext.panel.Tool):void;

  [ExtConfig]
  /**
   * Set to true will add a listener to the titleCmp property for the click event which will execute the
   * <code>toggle()</code> method. This option is only used when the <code>collapsible</code> property is set to true.
   * @default true
   * @see #toggle()
   * @see #collapsible
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#cfg-toggleOnTitleClick Original Ext JS documentation of 'toggleOnTitleClick'
   */
  public native function get toggleOnTitleClick():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set toggleOnTitleClick(value:Boolean):void;

  /**
   * Collapses the fieldset.
   * @return this
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#method-collapse Original Ext JS documentation of 'collapse'
   */
  public native function collapse():ext.form.FieldSet;

  /**
   * Creates the checkbox component. This is only called internally, but could be overridden in subclasses to
   * customize the checkbox's configuration or even return an entirely different component type.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#method-createCheckboxCmp Original Ext JS documentation of 'createCheckboxCmp'
   */
  protected native function createCheckboxCmp():ext.Component;

  /**
   * Creates the legend title component. This is only called internally, but could be overridden in subclasses to
   * customize the title component. If <code>toggleOnTitleClick</code> is set to true, a listener for the click event
   * will toggle the collapsed state of the FieldSet.
   * @see #toggleOnTitleClick
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#method-createTitleCmp Original Ext JS documentation of 'createTitleCmp'
   */
  protected native function createTitleCmp():ext.Component;

  /**
   * Creates the toggle button component. This is only called internally, but could be overridden in subclasses to
   * customize the toggle component.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#method-createToggleCmp Original Ext JS documentation of 'createToggleCmp'
   */
  protected native function createToggleCmp():ext.Component;

  /**
   * Expands the fieldset.
   * @return this
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#method-expand Original Ext JS documentation of 'expand'
   */
  public native function expand():ext.form.FieldSet;

  /**
   * Initializes the FieldAncestor's state; this must be called from the initComponent method of any components
   * importing this mixin.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldAncestor.html#method-initFieldAncestor Original Ext JS documentation of 'initFieldAncestor'
   */
  protected native function initFieldAncestor():void;

  /**
   * Fired when the error message of any field within the container changes.
   * @param field The sub-field whose active error changed
   * @param error The new active error message
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldAncestor.html#method-onFieldErrorChange Original Ext JS documentation of 'onFieldErrorChange'
   */
  protected native function onFieldErrorChange(field:ext.form.Labelable, error:String):void;

  /**
   * Fired when the validity of any field within the container changes.
   * @param field The sub-field whose validity changed
   * @param valid The new validity state
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldAncestor.html#method-onFieldValidityChange Original Ext JS documentation of 'onFieldValidityChange'
   */
  protected native function onFieldValidityChange(field:ext.form.field.Field, valid:Boolean):void;

  /**
   * Set the collapsed state of the fieldset.
   * @since 6.2.0
   * @param collapsed The collapsed state.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#method-setCollapsed Original Ext JS documentation of 'setCollapsed'
   */
  public native function setCollapsed(collapsed:Boolean):void;

  /**
   * Sets the title of this fieldset.
   * @param title The new title.
   * @return this
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#method-setTitle Original Ext JS documentation of 'setTitle'
   */
  public native function setTitle(title:String):ext.form.FieldSet;

  /**
   * Toggle the fieldset's collapsed state to the opposite of what it is currently.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.FieldSet.html#method-toggle Original Ext JS documentation of 'toggle'
   */
  public native function toggle():void;
}
}