package ext.form.field {
import ext.dom.Element;

[Uses("ext.form.field.BaseField")]
[Uses("ext.form.Labelable")]
[Uses("ext.Mixin")]
[Uses("ext.Base")]
[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Uses("ext.form.field.Field")]
[Native("Ext.form.field.Checkbox", require)]
/**
 * Single checkbox field. Can be used as a direct replacement for traditional checkbox fields. Also serves as a
 * parent class for <code>ext.form.field.Radio</code>.
 * <p><b>Labeling</b></p>
 * <p>In addition to the <code>ext.form.Labelable</code>, checkboxes
 * may be given an optional <code>boxLabel</code> which will be displayed immediately after checkbox. Also see
 * <code>ext.form.CheckboxGroup</code> for a convenient method of grouping related checkboxes.</p>
 * <p><b>Values</b></p>
 * <p>The main value of a checkbox is a boolean, indicating whether or not the checkbox is checked.
 * The following values will check the checkbox:</p>
 * <ul>
 * <li><code>true</code></li>
 * <li><code>'true'</code></li>
 * <li><code>'1'</code></li>
 * <li><code>'on'</code></li>
 * </ul>
 * <p>Any other value will un-check the checkbox.</p>
 * <p>In addition to the main boolean value, you may also specify a separate <code>inputValue</code>. This will be
 * sent as the parameter value when the form is <code>submitted</code>. You will want to set
 * this value if you have multiple checkboxes with the same <code>name</code>. If not specified, the value <code>on</code>
 * will be used.</p>
 * <p><b>Example usage</b></p>
 * <p><b>Example:</b></p>
 * <pre>
 * Ext.create('Ext.form.Panel', {
 *     bodyPadding: 10,
 *     width: 300,
 *     title: 'Pizza Order',
 *     items: [
 *         {
 *             xtype: 'fieldcontainer',
 *             fieldLabel: 'Toppings',
 *             defaultType: 'checkboxfield',
 *             items: [
 *                 {
 *                     boxLabel  : 'Anchovies',
 *                     name      : 'topping',
 *                     inputValue: '1',
 *                     id        : 'checkbox1'
 *                 }, {
 *                     boxLabel  : 'Artichoke Hearts',
 *                     name      : 'topping',
 *                     inputValue: '2',
 *                     checked   : true,
 *                     id        : 'checkbox2'
 *                 }, {
 *                     boxLabel  : 'Bacon',
 *                     name      : 'topping',
 *                     inputValue: '3',
 *                     id        : 'checkbox3'
 *                 }
 *             ]
 *         }
 *     ],
 *     bbar: [
 *         {
 *             text: 'Select Bacon',
 *             handler: function() {
 *                 Ext.getCmp('checkbox3').setValue(true);
 *             }
 *         },
 *         '-',
 *         {
 *             text: 'Select All',
 *             handler: function() {
 *                 Ext.getCmp('checkbox1').setValue(true);
 *                 Ext.getCmp('checkbox2').setValue(true);
 *                 Ext.getCmp('checkbox3').setValue(true);
 *             }
 *         },
 *         {
 *             text: 'Deselect All',
 *             handler: function() {
 *                 Ext.getCmp('checkbox1').setValue(false);
 *                 Ext.getCmp('checkbox2').setValue(false);
 *                 Ext.getCmp('checkbox3').setValue(false);
 *             }
 *         }
 *     ],
 *     renderTo: Ext.getBody()
 * });
 * </pre>
 * @see ext.form.field.Radio
 * @see ext.form.Labelable
 * @see #boxLabel
 * @see ext.form.CheckboxGroup
 * @see #inputValue
 * @see ext.form.BasicForm#submit()
 * @see #name
 * @see #on()
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html Original Ext JS documentation of 'Ext.form.field.Checkbox'
 */
public class Checkbox extends ext.form.field.BaseField {
  /**
   * @param config @inheritDoc
   */
  public function Checkbox(config:ext.form.field.Checkbox = null) {
    super();
  }

  [ExtConfig]
  /**
   * An optional string or <code>XTemplate</code> configuration to insert in the field markup
   * after the box label text. If an <code>XTemplate</code> is used, the component's
   * <i>subTpl data</i> serves as the context.
   * @see ext.form.field.BaseField#getSubTplData() subTpl data
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-afterBoxLabelTextTpl Original Ext JS documentation of 'afterBoxLabelTextTpl'
   */
  public native function get afterBoxLabelTextTpl():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set afterBoxLabelTextTpl(value:*):void;

  [ExtConfig]
  /**
   * An optional string or <code>XTemplate</code> configuration to insert in the field markup
   * after the box label element. If an <code>XTemplate</code> is used, the component's
   * <i>subTpl data</i> serves as the context.
   * @see ext.form.field.BaseField#getSubTplData() subTpl data
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-afterBoxLabelTpl Original Ext JS documentation of 'afterBoxLabelTpl'
   */
  public native function get afterBoxLabelTpl():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set afterBoxLabelTpl(value:*):void;

  [ExtConfig]
  /**
   * An optional string or <code>XTemplate</code> configuration to insert in the field markup
   * before the box label text. If an <code>XTemplate</code> is used, the component's
   * <i>subTpl data</i> serves as the context.
   * @see ext.form.field.BaseField#getSubTplData() subTpl data
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-beforeBoxLabelTextTpl Original Ext JS documentation of 'beforeBoxLabelTextTpl'
   */
  public native function get beforeBoxLabelTextTpl():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set beforeBoxLabelTextTpl(value:*):void;

  [ExtConfig]
  /**
   * An optional string or <code>XTemplate</code> configuration to insert in the field markup
   * before the box label element. If an <code>XTemplate</code> is used, the component's
   * <i>subTpl data</i> serves as the context.
   * @see ext.form.field.BaseField#getSubTplData() subTpl data
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-beforeBoxLabelTpl Original Ext JS documentation of 'beforeBoxLabelTpl'
   */
  public native function get beforeBoxLabelTpl():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set beforeBoxLabelTpl(value:*):void;

  [ExtConfig]
  /**
   * An optional text label that will appear next to the checkbox. Whether it appears before or after the checkbox is
   * determined by the <code>boxLabelAlign</code> config.
   * @see #boxLabelAlign
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-boxLabel Original Ext JS documentation of 'boxLabel'
   * @see #setBoxLabel()
   */
  public native function get boxLabel():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set boxLabel(value:String):void;

  [ExtConfig]
  /**
   * The position relative to the checkbox where the <code>boxLabel</code> should appear. Recognized values are 'before'
   * and 'after'.
   * @default 'after'
   * @see #boxLabel
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-boxLabelAlign Original Ext JS documentation of 'boxLabelAlign'
   */
  public native function get boxLabelAlign():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set boxLabelAlign(value:String):void;

  [ExtConfig]
  /**
   * An optional string or <code>XTemplate</code> configuration to insert in the field markup
   * inside the box label element (as attributes). If an <code>XTemplate</code> is used, the component's
   * <i>subTpl data</i> serves as the context.
   * @see ext.form.field.BaseField#getSubTplData() subTpl data
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-boxLabelAttrTpl Original Ext JS documentation of 'boxLabelAttrTpl'
   */
  public native function get boxLabelAttrTpl():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set boxLabelAttrTpl(value:*):void;

  [ExtConfig]
  /**
   * The CSS class to be applied to the <code>boxLabel</code> element
   * @default 'x-form-cb-label'
   * @see #boxLabel
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-boxLabelCls Original Ext JS documentation of 'boxLabelCls'
   */
  public native function get boxLabelCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set boxLabelCls(value:String):void;

  /**
   * A reference to the label element created for the <code>boxLabel</code>. Only present if the component has been
   * rendered and has a boxLabel configured.
   * @see #boxLabel
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#property-boxLabelEl Original Ext JS documentation of 'boxLabelEl'
   */
  public native function get boxLabelEl():ext.dom.Element;

  /**
   * @private
   */
  public native function set boxLabelEl(value:ext.dom.Element):void;

  [ExtConfig]
  /**
   * true if the checkbox should render initially checked
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-checked Original Ext JS documentation of 'checked'
   */
  public native function get checked():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set checked(value:Boolean):void;

  [ExtConfig]
  /**
   * The CSS class(es) added to the component's main element when it is in the checked state.
   * You can add your own class (checkedCls='myClass x-form-cb-checked') or replace the default
   * class altogether (checkedCls='myClass').
   * @default 'x-form-cb-checked'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-checkedCls Original Ext JS documentation of 'checkedCls'
   */
  public native function get checkedCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set checkedCls(value:String):void;

  [ExtConfig]
  /**
   * The default CSS class for the checkbox
   * @default 'x-form-field'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-fieldCls Original Ext JS documentation of 'fieldCls'
   */
  override public native function get fieldCls():String;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set fieldCls(value:String):void;

  [ExtConfig]
  /**
   * The CSS class to use when the checkbox receives focus
   * @default 'x-form-checkbox-focus'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-focusCls Original Ext JS documentation of 'focusCls'
   */
  override public native function get focusCls():String;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set focusCls(value:String):void;

  [ExtConfig]
  /**
   * A function called when the <code>checked</code> value changes (can be used instead of handling the <i>change event</i>).
   * <ul>
   * <li><code>checkbox</code> : ext.form.field.Checkbox (optional)
   * The Checkbox being toggled.
   * </li>
   * <li><code>checked</code> : Boolean (optional)
   * The new checked state of the checkbox.
   * </li>
   * </ul>
   * @see #checked
   * @see #event:onChange change event
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#property-checkbox Original Ext JS documentation of 'checkbox'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#property-checked Original Ext JS documentation of 'checked'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-handler Original Ext JS documentation of 'handler'
   */
  public native function get handler():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set handler(value:*):void;

  [ExtConfig]
  /**
   * The value that should go into the generated input element's value attribute and should be used as the parameter
   * value when submitting as part of a form.
   * @default 'on'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-inputValue Original Ext JS documentation of 'inputValue'
   */
  public native function get inputValue():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set inputValue(value:String):void;

  /**
   * <code>true</code> in this class to identify an object as an instantiated Checkbox, or subclass thereof.
   * @default true
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#property-isCheckbox Original Ext JS documentation of 'isCheckbox'
   */
  public native function get isCheckbox():Boolean;

  /**
   * @private
   */
  public native function set isCheckbox(value:Boolean):void;

  [ExtConfig]
  /**
   * The value to use for <code>getModelData()</code> when checked.
   * @default true
   * @since 6.2.1
   * @see #getModelData()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-modelValue Original Ext JS documentation of 'modelValue'
   */
  public native function get modelValue():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set modelValue(value:*):void;

  [ExtConfig]
  /**
   * The value to use for <code>getModelData()</code> when unchecked.
   * @default false
   * @since 6.2.1
   * @see #getModelData()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-modelValueUnchecked Original Ext JS documentation of 'modelValueUnchecked'
   */
  public native function get modelValueUnchecked():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set modelValueUnchecked(value:*):void;

  /**
   * The original value of the field as configured in the <code>checked</code> configuration, or as loaded by the last
   * form load operation if the form's <code>trackResetOnLoad</code> setting is <code>true</code>.
   * @default checked
   * @see #checked
   * @see ext.form.BasicForm#trackResetOnLoad
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#property-originalValue Original Ext JS documentation of 'originalValue'
   */
  override public native function get originalValue():*;

  /**
   * @private
   */
  override public native function set originalValue(value:*):void;

  [ExtConfig]
  /**
   * An object to use as the scope ('this' reference) of the <code>handler</code> function.
   * <p>Defaults to this Checkbox.</p>
   * @see #handler
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-scope Original Ext JS documentation of 'scope'
   */
  public native function get scope():Object;

  [ExtConfig]
  /**
   * @private
   */
  public native function set scope(value:Object):void;

  [ExtConfig]
  /**
   * If configured, this will be submitted as the checkbox's value during form submit if the checkbox is unchecked. By
   * default this is undefined, which results in nothing being submitted for the checkbox field when the form is
   * submitted (the default behavior of HTML checkboxes).
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#cfg-uncheckedValue Original Ext JS documentation of 'uncheckedValue'
   */
  public native function get uncheckedValue():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set uncheckedValue(value:String):void;

  /**
   * Returns the checked state of the checkbox.
   * @return True if checked, else false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#method-getRawValue Original Ext JS documentation of 'getRawValue'
   */
  override public native function getRawValue():String;

  /**
   * Returns the submit value for the checkbox which can be used when submitting forms.
   * @return If checked the <code>inputValue</code> is returned; otherwise the <code>uncheckedValue</code>
   * (or null if the latter is not configured).
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#method-getSubmitValue Original Ext JS documentation of 'getSubmitValue'
   * @see #inputValue
   * @see #uncheckedValue
   */
  override public native function getSubmitValue():String;

  /**
   * Returns the checked state of the checkbox.
   * @return True if checked, else false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#method-getValue Original Ext JS documentation of 'getValue'
   */
  override public native function getValue():*;

  /**
   * Sets the <code>boxLabel</code> for this checkbox.
   * @param boxLabel The new label
   * @see #boxLabel
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#method-setBoxLabel Original Ext JS documentation of 'setBoxLabel'
   */
  public native function setBoxLabel(boxLabel:String):void;

  /**
   * Sets the checked state of the checkbox.
   * @param value The value to set
   * @return the new checked state of the checkbox
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#method-setRawValue Original Ext JS documentation of 'setRawValue'
   */
  override public native function setRawValue(value:Object):Object;

  /**
   * Sets the checked state of the checkbox, and invokes change detection.
   * @param value The value to set
   * @return this
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Checkbox.html#method-setValue Original Ext JS documentation of 'setValue'
   */
  override public native function setValue(value:*):ext.form.field.IField;
}
}