package ext.form.field {

[Uses("ext.form.field.BaseField")]
[Uses("ext.form.Labelable")]
[Uses("ext.Mixin")]
[Uses("ext.Base")]
[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Uses("ext.form.field.Field")]
[Native("Ext.form.field.Display", require)]
/**
 * A display-only text field which is not validated and not submitted. This is useful for when you want to display a
 * value from a form's <i>loaded data</i> but do not want to allow the user to edit or submit that
 * value. The value can be optionally <i>HTML encoded</i> if it contains HTML markup that you do not want
 * to be rendered.
 * <p>If you have more complex content, or need to include components within the displayed content, also consider using a
 * <code>ext.form.FieldContainer</code> instead.</p>
 * <p>Example:</p>
 * <p><b>Example:</b></p>
 * <pre>
 * Ext.create('Ext.form.Panel', {
 *     renderTo: Ext.getBody(),
 *     width: 175,
 *     height: 150,
 *     bodyPadding: 10,
 *     title: 'Final Score',
 *     items: [{
 *         xtype: 'displayfield',
 *         fieldLabel: 'Home',
 *         name: 'home_score',
 *         value: '10'
 *     }, {
 *         xtype: 'displayfield',
 *         fieldLabel: 'Visitor',
 *         name: 'visitor_score',
 *         value: '11'
 *     }],
 *     buttons: [{
 *         text: 'Update'
 *     }]
 * });
 * </pre>
 * @see ext.form.BasicForm#load() loaded data
 * @see #htmlEncode HTML encoded
 * @see ext.form.FieldContainer
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Display.html Original Ext JS documentation of 'Ext.form.field.Display'
 */
public class DisplayField extends ext.form.field.BaseField {
  /**
   * @param config @inheritDoc
   */
  public function DisplayField(config:ext.form.field.DisplayField = null) {
    super();
  }

  [ExtConfig]
  /**
   * The default CSS class for the field.
   * @default "x-form-display-field"
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Display.html#cfg-fieldCls Original Ext JS documentation of 'fieldCls'
   */
  override public native function get fieldCls():String;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set fieldCls(value:String):void;

  [ExtConfig]
  /**
   * True to escape HTML in text when rendering it.
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Display.html#cfg-htmlEncode Original Ext JS documentation of 'htmlEncode'
   */
  public native function get htmlEncode():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set htmlEncode(value:Boolean):void;

  [ExtConfig]
  /**
   * A function to transform the raw value for display in the field.
   * <pre>
   * Ext.create('Ext.form.Panel', {
   *     renderTo: document.body,
   *     width: 175,
   *     bodyPadding: 10,
   *     title: 'Final Score',
   *     items: [{
   *         xtype: 'displayfield',
   *         fieldLabel: 'Grade',
   *         name: 'final_grade',
   *         value: 68,
   *         renderer: function (value, field) {
   *             var color = (value &lt; 70) ? 'red' : 'black';
   *             return '&lt;span style="color:' + color + ';"&gt;' + value + '&lt;/span&gt;';
   *         }
   *     }]
   * });
   * </pre>
   * <ul>
   * <li><code>value</code> : Object
   * The raw field <code>value</code>
   * </li>
   * <li><code>field</code> : ext.form.field.DisplayField
   * The display field
   * </li>
   * <li><code>null</code> : String
   * displayValue The HTML string to be rendered
   * </li>
   * </ul>
   * @see #value
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Display.html#cfg-renderer Original Ext JS documentation of 'renderer'
   */
  public native function get renderer():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set renderer(value:*):void;

  [ExtConfig]
  /**
   * The scope to execute the <code>renderer</code> function. Defaults to this.
   * @see #renderer
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Display.html#cfg-scope Original Ext JS documentation of 'scope'
   */
  public native function get scope():Object;

  [ExtConfig]
  /**
   * @private
   */
  public native function set scope(value:Object):void;
}
}