package ext.grid.column {

[Uses("ext.grid.column.Column")]
[Uses("ext.grid.header.HeaderContainer")]
[Uses("ext.util.FocusableContainer")]
[Uses("ext.Mixin")]
[Uses("ext.Base")]
[Uses("ext.container.Container")]
[Uses("ext.mixin.Queryable")]
[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Uses("ext.mixin.Container")]
[Native("Ext.grid.column.Action", require)]
/**
 * A Grid header type which renders an icon, or a series of icons in a grid cell, and offers a scoped click
 * handler for each icon.
 * <p><b>Example:</b></p>
 * <pre>
 * // Init the singleton.  Any tag-based quick tips will start working.
 * Ext.tip.QuickTipManager.init();
 *
 * Ext.create('Ext.data.Store', {
 *     storeId:'employeeStore',
 *     fields:['firstname', 'lastname', 'seniority', 'dep', 'hired'],
 *     data:[
 *         {firstname:"Michael", lastname:"Scott"},
 *         {firstname:"Dwight", lastname:"Schrute"},
 *         {firstname:"Jim", lastname:"Halpert"},
 *         {firstname:"Kevin", lastname:"Malone"},
 *         {firstname:"Angela", lastname:"Martin"}
 *     ]
 * });
 *
 * Ext.create('Ext.grid.Panel', {
 *     title: 'Action Column Demo',
 *     store: Ext.data.StoreManager.lookup('employeeStore'),
 *     columns: [
 *         {text: 'First Name',  dataIndex:'firstname'},
 *         {text: 'Last Name',  dataIndex:'lastname'},
 *         {
 *             xtype:'actioncolumn',
 *             width:50,
 *             items: [{
 *                 iconCls: 'x-fa fa-cog',
 *                 tooltip: 'Edit',
 *                 handler: function(grid, rowIndex, colIndex) {
 *                     var rec = grid.getStore().getAt(rowIndex);
 *                     alert("Edit " + rec.get('firstname'));
 *                 }
 *             },{
 *                 icon: 'extjs-build/examples/restful/images/delete.png',
 *                 tooltip: 'Delete',
 *                 handler: function(grid, rowIndex, colIndex) {
 *                     var rec = grid.getStore().getAt(rowIndex);
 *                     alert("Terminate " + rec.get('firstname'));
 *                 }
 *             }]
 *         }
 *     ],
 *     width: 250,
 *     renderTo: Ext.getBody()
 * });
 * </pre>
 * <p>The action column can be at any index in the columns array, and a grid can have any number of
 * action columns.</p>
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html Original Ext JS documentation of 'Ext.grid.column.Action'
 */
public class ActionColumn extends ext.grid.column.Column {
  /**
   * @param config @inheritDoc
   */
  public function ActionColumn(config:ext.grid.column.ActionColumn = null) {
    super();
  }

  [ExtConfig]
  /**
   * The alt text to use for the image element.
   * @default ''
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#cfg-altText Original Ext JS documentation of 'altText'
   */
  public native function get altText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set altText(value:String):void;

  [ExtConfig]
  /**
   * If true, the action will not respond to click events, and will be displayed semi-opaque.
   * <p>This Column may also be disabled on a row by row basis by configuring a <code>isDisabled</code> method.</p>
   * @see #isDisabled
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#cfg-disabled Original Ext JS documentation of 'disabled'
   * @see #setDisabled()
   */
  override public native function get disabled():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  override public native function set disabled(value:Boolean):void;

  [ExtConfig]
  /**
   * A function which returns the CSS class to apply to the icon image.
   * <p>For information on using the icons provided in the SDK see <code>iconCls</code>.</p>
   * <ul>
   * <li><code>v</code> : Object (optional)
   * The value of the column's configured field (if any).
   * </li>
   * <li><code>metadata</code> : Object (optional)
   * An object in which you may set the following attributes:
   * <ul>
   * <li><code>css</code> : String (optional)
   * A CSS class name to add to the cell's TD element.
   * </li>
   * <li><code>attr</code> : String (optional)
   * An HTML attribute definition string to apply to the data container
   * element <i>within</i> the table cell (e.g. 'style="color:red;"').
   * </li>
   * </ul>
   * </li>
   * <li><code>r</code> : ext.data.Model (optional)
   * The Record providing the data.
   * </li>
   * <li><code>rowIndex</code> : Number (optional)
   * The row index.
   * </li>
   * <li><code>colIndex</code> : Number (optional)
   * The column index.
   * </li>
   * <li><code>store</code> : ext.data.Store (optional)
   * The Store which is providing the data Model.
   * </li>
   * </ul>
   * @see #iconCls
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-v Original Ext JS documentation of 'v'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-css Original Ext JS documentation of 'css'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-attr Original Ext JS documentation of 'attr'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-metadata Original Ext JS documentation of 'metadata'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-r Original Ext JS documentation of 'r'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-rowIndex Original Ext JS documentation of 'rowIndex'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-colIndex Original Ext JS documentation of 'colIndex'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-store Original Ext JS documentation of 'store'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#cfg-getClass Original Ext JS documentation of 'getClass'
   */
  public native function get getClass():Function;

  [ExtConfig]
  /**
   * @private
   */
  public native function set getClass(value:Function):void;

  [ExtConfig]
  /**
   * A function which returns the tooltip string for any row.
   * <p><i>Note</i>: Outside of an Ext.application() use of this config requires
   * <code>ext.tip.SQuickTipManager#init()</code> to be called.</p>
   * <pre>
   * Ext.tip.QuickTipManager.init();
   *
   * Ext.create('Ext.data.Store', {
   *     storeId: 'employeeStore',
   *     fields: ['firstname', 'grade'],
   *     data: [{
   *         firstname: "Michael",
   *         grade: 50
   *     }, {
   *         firstname: "Dwight",
   *         grade: 100
   *     }]
   * });
   *
   * Ext.create('Ext.grid.Panel', {
   *     title: 'Action Column Demo',
   *     store: Ext.data.StoreManager.lookup('employeeStore'),
   *     columns: [{
   *         text: 'First Name',
   *         dataIndex: 'firstname'
   *     }, {
   *         text: 'Last Name',
   *         dataIndex: 'grade'
   *     }, {
   *         xtype: 'actioncolumn',
   *         width: 50,
   *         icon: 'sample/icons/action-icons.png',
   *         getTip: function(value, metadata, record, row, col, store) {
   *             var avg = store.average('grade'),
   *                 grade = record.get('grade');
   *
   *             if (grade &lt; avg) {
   *                 metadata.tdCls = "below-average";
   *             }
   *
   *             return grade &gt; 70 ? 'Pass' : 'Fail';
   *         },
   *         handler: function(grid, rowIndex, colIndex) {
   *             var rec = grid.getStore().getAt(rowIndex);
   *             alert("Edit " + rec.get('firstname'));
   *         }
   *     }],
   *     width: 250,
   *     renderTo: document.body
   * });
   * </pre>
   * <ul>
   * <li><code>value</code> : Object
   * The value of the column's configured field (if any).
   * </li>
   * <li><code>metadata</code> : Object
   * An object in which you may set the following attributes:
   * </li>
   * <li><code>record</code> : ext.data.Model
   * The Record providing the data.
   * </li>
   * <li><code>rowIndex</code> : Number
   * The row index.
   * </li>
   * <li><code>colIndex</code> : Number
   * The column index.
   * </li>
   * <li><code>store</code> : ext.data.Store
   * The Store which is providing the data Model.
   * </li>
   * <li><code>null</code> : String
   * tip The tip text
   * </li>
   * </ul>
   * @see ext.tip.SQuickTipManager#init()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#cfg-getTip Original Ext JS documentation of 'getTip'
   */
  public native function get getTip():Function;

  [ExtConfig]
  /**
   * @private
   */
  public native function set getTip(value:Function):void;

  [ExtConfig]
  /**
   * A numeric unicode character code to use as the icon. The default font-family
   * for glyphs can be set globally using
   * <code>glyphFontFamily</code> application
   * config or the <i>Ext.setGlyphFontFamily()</i> method.
   * It is initially set to <code>'Pictos'</code>.
   * <p>The following shows how to set the glyph using the font icons provided in the
   * SDK (assuming the font-family has been configured globally):</p>
   * <pre>
   * // assumes the glyphFontFamily is "Pictos"
   * glyph: 'x48'       // the "home" icon (H character)
   *
   * // assumes the glyphFontFamily is "Pictos"
   * glyph: 72          // The "home" icon (H character)
   *
   * // assumes the glyphFontFamily is "Pictos"
   * glyph: 'H'         // the "home" icon
   * </pre>
   * <p>Alternatively, this config option accepts a string with the charCode and
   * font-family separated by the <code>&#64;</code> symbol.</p>
   * <pre>
   * // using Font Awesome
   * glyph: 'xf015&#64;FontAwesome'     // the "home" icon
   *
   * // using Pictos
   * glyph: 'H&#64;Pictos'              // the "home" icon
   * </pre>
   * <p>Depending on the theme you're using, you may need include the font icon
   * packages in your application in order to use the icons included in the
   * SDK. For more information see:</p>
   * <ul>
   * <li><a href="http://fortawesome.github.io/Font-Awesome/cheatsheet/">Font Awesome icons</a></li>
   * <li><a href="../guides/core_concepts/font_ext.html">Pictos icons</a></li>
   * <li><a href="../guides/core_concepts/theming.html">Theming Guide</a></li>
   * </ul>
   * @since 6.2.0
   * @see ext.app.Application#glyphFontFamily
   * @see ext.SExt#setGlyphFontFamily() Ext.setGlyphFontFamily()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#cfg-glyph Original Ext JS documentation of 'glyph'
   */
  public native function get glyph():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set glyph(value:*):void;

  [ExtConfig]
  /**
   * A function called when the icon is clicked.
   * <ul>
   * <li><code>view</code> : ext.view.TableView (optional)
   * The owning TableView.
   * </li>
   * <li><code>rowIndex</code> : Number (optional)
   * The row index clicked on.
   * </li>
   * <li><code>colIndex</code> : Number (optional)
   * The column index clicked on.
   * </li>
   * <li><code>item</code> : Object (optional)
   * The clicked item (or this Column if multiple <code>items</code> were not configured).
   * </li>
   * <li><code>e</code> : js.Event (optional)
   * The click event.
   * </li>
   * <li><code>record</code> : ext.data.Model (optional)
   * The Record underlying the clicked row.
   * </li>
   * <li><code>row</code> : js.HTMLElement (optional)
   * The table row clicked upon.
   * </li>
   * </ul>
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-view Original Ext JS documentation of 'view'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-rowIndex Original Ext JS documentation of 'rowIndex'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-colIndex Original Ext JS documentation of 'colIndex'
   * @see #items
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-item Original Ext JS documentation of 'item'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-e Original Ext JS documentation of 'e'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-record Original Ext JS documentation of 'record'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-row Original Ext JS documentation of 'row'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#cfg-handler Original Ext JS documentation of 'handler'
   */
  public native function get handler():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set handler(value:*):void;

  [ExtConfig]
  /**
   * Path to an image to use as an icon.
   * <p>For instructions on how you can use icon fonts including those distributed in
   * the SDK see <code>iconCls</code>.</p>
   * @default Ext#BLANK_IMAGE_URL
   * @see #iconCls
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#cfg-icon Original Ext JS documentation of 'icon'
   */
  public native function get icon():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set icon(value:String):void;

  [ExtConfig]
  /**
   * One or more space separated CSS classes to be applied to the icon element.
   * The CSS rule(s) applied should specify a background image to be used as the
   * icon.
   * <p>An example of specifying a custom icon class would be something like:</p>
   * <pre>
   * // specify the property in the config for the class:
   * iconCls: 'my-home-icon'
   *
   * // css rule specifying the background image to be used as the icon image:
   * .my-home-icon {
   *     background-image: url(../images/my-home-icon.gif) !important;
   * }
   * </pre>
   * <p>In addition to specifying your own classes, you can use the font icons
   * provided in the SDK using the following syntax:</p>
   * <pre>
   * // using Font Awesome
   * iconCls: 'x-fa fa-home'
   *
   * // using Pictos
   * iconCls: 'pictos pictos-home'
   * </pre>
   * <p>Depending on the theme you're using, you may need include the font icon
   * packages in your application in order to use the icons included in the
   * SDK. For more information see:</p>
   * <ul>
   * <li><a href="http://fortawesome.github.io/Font-Awesome/cheatsheet/">Font Awesome icons</a></li>
   * <li><a href="../guides/core_concepts/font_ext.html">Pictos icons</a></li>
   * <li><a href="../guides/core_concepts/theming.html">Theming Guide</a>
   * <b>Note:</b> To determine the class dynamically, configure the Column with
   * a <code>getClass</code> function.</li>
   * </ul>
   * @see #getClass
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#cfg-iconCls Original Ext JS documentation of 'iconCls'
   */
  public native function get iconCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set iconCls(value:String):void;

  [ExtConfig("isDisabled")]
  /**
   * A function which determines whether the action item for any row is disabled and returns <code>true</code> or <code>false</code>.
   * <ul>
   * <li><code>view</code> : ext.view.TableView (optional)
   * The owning TableView.
   * </li>
   * <li><code>rowIndex</code> : Number (optional)
   * The row index.
   * </li>
   * <li><code>colIndex</code> : Number (optional)
   * The column index.
   * </li>
   * <li><code>item</code> : Object (optional)
   * The clicked item (or this Column if multiple <code>items</code> were not configured).
   * </li>
   * <li><code>record</code> : ext.data.Model (optional)
   * The Record underlying the row.
   * </li>
   * </ul>
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-view Original Ext JS documentation of 'view'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-rowIndex Original Ext JS documentation of 'rowIndex'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-colIndex Original Ext JS documentation of 'colIndex'
   * @see #items
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-item Original Ext JS documentation of 'item'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-record Original Ext JS documentation of 'record'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#cfg-isDisabled Original Ext JS documentation of 'isDisabled'
   */
  public native function get isDisabled_():Function;

  [ExtConfig("isDisabled")]
  /**
   * @private
   */
  public native function set isDisabled_(value:Function):void;

  [ExtConfig]
  /**
   * Default ARIA role for each action item.
   * @default "button"
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#cfg-itemAriaRole Original Ext JS documentation of 'itemAriaRole'
   */
  public native function get itemAriaRole():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set itemAriaRole(value:String):void;

  [ExtConfig]
  /**
   * Default tabIndex attribute value for each action item.
   * @default 0
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#cfg-itemTabIndex Original Ext JS documentation of 'itemTabIndex'
   */
  public native function get itemTabIndex():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set itemTabIndex(value:Number):void;

  [ExtConfig]
  /**
   * An array of action items copied from the configured <code>items</code> configuration. Each will have
   * an <code>enable</code> and <code>disable</code> method added which will enable and disable the associated action, and
   * update the displayed icon accordingly.
   * @see #items
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#property-items Original Ext JS documentation of 'items'
   */
  override public native function get items():Array;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set items(value:Array):void;

  [ExtConfig]
  /**
   * Text to display in this column's menu item if no <code>text</code> was specified as a header.
   * @default <i>Actions</i>
   * @see #text
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#cfg-menuText Original Ext JS documentation of 'menuText'
   */
  override public native function get menuText():String;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set menuText(value:String):void;

  [ExtConfig]
  /**
   * The scope (<code>this</code> reference) in which the <code>handler</code>,
   * <code>getClass</code>, <code>isDisabled</code> and <code>getTip</code> functions
   * are executed.
   * Defaults to this Column.
   * @see #handler
   * @see #getClass
   * @see #isDisabled
   * @see #getTip
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#cfg-scope Original Ext JS documentation of 'scope'
   */
  override public native function get scope():Object;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set scope(value:Object):void;

  [ExtConfig]
  /**
   * Prevent grid selection upon click.
   * Beware that if you allow for the selection to happen then the selection model will steal focus from
   * any possible floating window (like a message box) raised in the handler. This will prevent closing the
   * window when pressing the Escape button since it will no longer contain a focused component.
   * @default true
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#cfg-stopSelection Original Ext JS documentation of 'stopSelection'
   */
  public native function get stopSelection():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set stopSelection(value:Boolean):void;

  [ExtConfig]
  /**
   * A tooltip message to be displayed on hover. <code>Ext.tip.QuickTipManager</code> must
   * have been initialized.
   * <p>The tooltip may also be determined on a row by row basis by configuring a <code>getTip</code> method.</p>
   * @see ext.tip.SQuickTipManager#init()
   * @see #getTip
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#cfg-tooltip Original Ext JS documentation of 'tooltip'
   */
  override public native function get tooltip():String;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set tooltip(value:String):void;

  /**
   * Disables this ActionColumn's action at the specified index.
   * @param silent
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#method-disableAction Original Ext JS documentation of 'disableAction'
   */
  public native function disableAction(index:*, silent:Boolean = false):void;

  /**
   * Enables this ActionColumn's action at the specified index.
   * @param silent
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.Action.html#method-enableAction Original Ext JS documentation of 'enableAction'
   */
  public native function enableAction(index:*, silent:Boolean = false):void;
}
}