package ext.menu {
import ext.Component;
import ext.mixin.IQueryable;

[Uses("ext.Component")]
[Uses("ext.mixin.Queryable")]
[Uses("ext.Base")]
[Uses("ext.util.Animate")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.Mixin")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Native("Ext.menu.Item", require)]
/**
 * @see ext.menu.events.ItemEvent.ACTIVATE
 * @eventType ext.menu.events.ItemEvent.ACTIVATE
 */
[Event(name = 'onActivate', type = 'ext.menu.events.ItemEvent')]
/**
 * @see ext.menu.events.Item_eEvent.CLICK
 * @eventType ext.menu.events.Item_eEvent.CLICK
 */
[Event(name = 'onClick', type = 'ext.menu.events.Item_eEvent')]
/**
 * @see ext.menu.events.ItemEvent.DEACTIVATE
 * @eventType ext.menu.events.ItemEvent.DEACTIVATE
 */
[Event(name = 'onDeactivate', type = 'ext.menu.events.ItemEvent')]
/**
 * @see ext.menu.events.Item_oldIcon_newIconEvent.ICON_CHANGE
 * @eventType ext.menu.events.Item_oldIcon_newIconEvent.ICON_CHANGE
 */
[Event(name = 'onIconChange', type = 'ext.menu.events.Item_oldIcon_newIconEvent')]
/**
 * @see ext.menu.events.Item_oldText_newTextEvent.TEXT_CHANGE
 * @eventType ext.menu.events.Item_oldText_newTextEvent.TEXT_CHANGE
 */
[Event(name = 'onTextChange', type = 'ext.menu.events.Item_oldText_newTextEvent')]
/**
 * A base class for all menu items that require menu-related functionality such as click handling,
 * sub-menus, icons, etc.
 * <p><b>Example:</b></p>
 * <pre>
 * Ext.create('Ext.menu.Menu', {
 *     width: 100,
 *     height: 100,
 *     floating: false,  // usually you want this set to True (default)
 *     renderTo: Ext.getBody(),  // usually rendered by it's containing component
 *     items: [{
 *         text: 'icon item',
 *         iconCls: 'add16'
 *     },{
 *         text: 'text item'
 *     },{
 *         text: 'plain item',
 *         plain: true
 *     }]
 * });
 * </pre>
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html Original Ext JS documentation of 'Ext.menu.Item'
 */
public class Item extends ext.Component implements ext.mixin.IQueryable {
  /**
   * @param config @inheritDoc
   */
  public function Item(config:ext.menu.Item = null) {
    super();
  }

  /**
   * Whether or not this item is currently activated
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#property-activated Original Ext JS documentation of 'activated'
   */
  public native function get activated():Boolean;

  /**
   * @private
   */
  public native function set activated(value:Boolean):void;

  [ExtConfig]
  /**
   * The CSS class added to the menu item when the item is focused.
   * @default Ext.baseCSSPrefix + 'menu-item-active'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-activeCls Original Ext JS documentation of 'activeCls'
   */
  public native function get activeCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set activeCls(value:String):void;

  [Deprecated(replacement = "focusable", since = "5.1.0")]
  [ExtConfig]
  /**
   * Whether or not this menu item can be focused.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-canActivate Original Ext JS documentation of 'canActivate'
   */
  public native function get canActivate():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set canActivate(value:Boolean):void;

  [ExtConfig]
  /**
   * The delay in milliseconds to wait before hiding the menu after clicking the menu item.
   * This only has an effect when <code>hideOnClick: true</code>.
   * @default 0
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-clickHideDelay Original Ext JS documentation of 'clickHideDelay'
   */
  public native function get clickHideDelay():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set clickHideDelay(value:Number):void;

  [ExtConfig]
  /**
   * Whether or not to destroy any associated sub-menu when this item is destroyed.
   * @default true
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-destroyMenu Original Ext JS documentation of 'destroyMenu'
   */
  public native function get destroyMenu():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set destroyMenu(value:Boolean):void;

  [ExtConfig]
  /**
   * The CSS class added to the menu item when the item is disabled.
   * @default Ext.baseCSSPrefix + 'menu-item-disabled'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-disabledCls Original Ext JS documentation of 'disabledCls'
   */
  override public native function get disabledCls():String;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set disabledCls(value:String):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * A numeric unicode character code to use as the icon. The default font-family
   * for glyphs can be set globally using
   * <code>glyphFontFamily</code> application
   * config or the <i>Ext.setGlyphFontFamily()</i> method.
   * It is initially set to <code>'Pictos'</code>.
   * <p>The following shows how to set the glyph using the font icons provided in the
   * SDK (assuming the font-family has been configured globally):</p>
   * <pre>
   * // assumes the glyphFontFamily is "Pictos"
   * glyph: 'x48'       // the "home" icon (H character)
   *
   * // assumes the glyphFontFamily is "Pictos"
   * glyph: 72          // The "home" icon (H character)
   *
   * // assumes the glyphFontFamily is "Pictos"
   * glyph: 'H'         // the "home" icon
   * </pre>
   * <p>Alternatively, this config option accepts a string with the charCode and
   * font-family separated by the <code>&#64;</code> symbol.</p>
   * <pre>
   * // using Font Awesome
   * glyph: 'xf015&#64;FontAwesome'     // the "home" icon
   *
   * // using Pictos
   * glyph: 'H&#64;Pictos'              // the "home" icon
   * </pre>
   * <p>Depending on the theme you're using, you may need include the font icon
   * packages in your application in order to use the icons included in the
   * SDK. For more information see:</p>
   * <ul>
   * <li><a href="http://fortawesome.github.io/Font-Awesome/cheatsheet/">Font Awesome icons</a></li>
   * <li><a href="../guides/core_concepts/font_ext.html">Pictos icons</a></li>
   * <li><a href="../guides/core_concepts/theming.html">Theming Guide</a></li>
   * </ul>
   * @see ext.app.Application#glyphFontFamily
   * @see ext.SExt#setGlyphFontFamily() Ext.setGlyphFontFamily()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-glyph Original Ext JS documentation of 'glyph'
   * @see #getGlyph()
   * @see #setGlyph()
   */
  public native function get glyph():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set glyph(value:*):void;

  [ExtConfig]
  /**
   * A function called when the menu item is clicked (can be used instead of <code>event:onClick</code> event).
   * <ul>
   * <li><code>item</code> : ext.menu.Item (optional)
   * The item that was clicked
   * </li>
   * <li><code>e</code> : ext.event.Event (optional)
   * The underlying <code>ext.event.Event</code>.
   * </li>
   * </ul>
   * @see #event:onClick
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#property-item Original Ext JS documentation of 'item'
   * @see ext.event.Event
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#property-e Original Ext JS documentation of 'e'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-handler Original Ext JS documentation of 'handler'
   * @see #setHandler()
   */
  public native function get handler():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set handler(value:*):void;

  [ExtConfig]
  /**
   * Whether to not to hide the owning menu when this item is clicked.
   * @default true
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-hideOnClick Original Ext JS documentation of 'hideOnClick'
   */
  public native function get hideOnClick():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set hideOnClick(value:Boolean):void;

  [ExtConfig]
  /**
   * The href attribute to use for the underlying anchor link.
   * @default '#'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-href Original Ext JS documentation of 'href'
   */
  public native function get href():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set href(value:String):void;

  [ExtConfig]
  /**
   * The target attribute to use for the underlying anchor link.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-hrefTarget Original Ext JS documentation of 'hrefTarget'
   */
  public native function get hrefTarget():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set hrefTarget(value:String):void;

  [ExtConfig]
  /**
   * Path to an image to use as an icon.
   * <p>For instructions on how you can use icon fonts including those distributed in
   * the SDK see <code>iconCls</code>.</p>
   * @default Ext#BLANK_IMAGE_URL
   * @see #iconCls
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-icon Original Ext JS documentation of 'icon'
   * @see #setIcon()
   */
  public native function get icon():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set icon(value:String):void;

  [ExtConfig]
  /**
   * One or more space separated CSS classes to be applied to the icon element.
   * The CSS rule(s) applied should specify a background image to be used as the
   * icon.
   * <p>An example of specifying a custom icon class would be something like:</p>
   * <pre>
   * // specify the property in the config for the class:
   * iconCls: 'my-home-icon'
   *
   * // css rule specifying the background image to be used as the icon image:
   * .my-home-icon {
   *     background-image: url(../images/my-home-icon.gif) !important;
   * }
   * </pre>
   * <p>In addition to specifying your own classes, you can use the font icons
   * provided in the SDK using the following syntax:</p>
   * <pre>
   * // using Font Awesome
   * iconCls: 'x-fa fa-home'
   *
   * // using Pictos
   * iconCls: 'pictos pictos-home'
   * </pre>
   * <p>Depending on the theme you're using, you may need include the font icon
   * packages in your application in order to use the icons included in the
   * SDK. For more information see:</p>
   * <ul>
   * <li><a href="http://fortawesome.github.io/Font-Awesome/cheatsheet/">Font Awesome icons</a></li>
   * <li><a href="../guides/core_concepts/font_ext.html">Pictos icons</a></li>
   * <li><a href="../guides/core_concepts/theming.html">Theming Guide</a></li>
   * </ul>
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-iconCls Original Ext JS documentation of 'iconCls'
   * @see #setIconCls()
   */
  public native function get iconCls():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set iconCls(value:String):void;

  /**
   * <code>true</code> in this class to identify an object as an instantiated Menu Item, or subclass thereof.
   * @default true
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#property-isMenuItem Original Ext JS documentation of 'isMenuItem'
   */
  public native function get isMenuItem():Boolean;

  /**
   * @private
   */
  public native function set isMenuItem(value:Boolean):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The sub-menu associated with this item, if one was configured.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#property-menu Original Ext JS documentation of 'menu'
   * @see #getMenu()
   * @see #setMenu()
   */
  public native function get menu():ext.menu.Menu;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set menu(value:ext.menu.Menu):void;

  [ExtConfig]
  /**
   * The default <code>Ext.util.Positionable.getAlignToXY</code> anchor position value for this
   * item's sub-menu relative to this item's position.
   * @default 'tl-tr?'
   * @see ext.util.Positionable#getAlignToXY()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-menuAlign Original Ext JS documentation of 'menuAlign'
   */
  public native function get menuAlign():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set menuAlign(value:String):void;

  [ExtConfig]
  /**
   * The delay in milliseconds before this item's sub-menu expands after this item is moused over.
   * @default 200
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-menuExpandDelay Original Ext JS documentation of 'menuExpandDelay'
   */
  public native function get menuExpandDelay():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set menuExpandDelay(value:Number):void;

  [ExtConfig]
  /**
   * The delay in milliseconds before this item's sub-menu hides after this item is moused out.
   * @default 200
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-menuHideDelay Original Ext JS documentation of 'menuHideDelay'
   */
  public native function get menuHideDelay():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set menuHideDelay(value:Number):void;

  /**
   * The parent Menu of this item.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#property-parentMenu Original Ext JS documentation of 'parentMenu'
   */
  public native function get parentMenu():ext.menu.Menu;

  /**
   * @private
   */
  public native function set parentMenu(value:ext.menu.Menu):void;

  [ExtConfig]
  /**
   * Whether or not this item is plain text/html with no icon or visual submenu indication.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-plain Original Ext JS documentation of 'plain'
   */
  public native function get plain():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set plain(value:Boolean):void;

  [ExtConfig]
  /**
   * The text/html to display in this item.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-text Original Ext JS documentation of 'text'
   * @see #setText()
   */
  public native function get text():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set text(value:String):void;

  [ExtConfig]
  /**
   * The tooltip for the button - can be a string to be used as innerHTML (html tags are accepted) or
   * QuickTips config object.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-tooltip Original Ext JS documentation of 'tooltip'
   * @see #setTooltip()
   */
  public native function get tooltip():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set tooltip(value:*):void;

  [ExtConfig]
  /**
   * The type of tooltip to use. Either 'qtip' for QuickTips or 'title' for title attribute.
   * @default 'qtip'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#cfg-tooltipType Original Ext JS documentation of 'tooltipType'
   */
  public native function get tooltipType():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set tooltipType(value:String):void;

  /**
   * @inheritDoc
   */
  public native function child(selector:* = undefined):ext.Component;

  /**
   * @inheritDoc
   */
  public native function down(selector:* = undefined):ext.Component;

  /**
   * Returns the value of <code>glyph</code>.
   * @see #glyph
   */
  public native function getGlyph():*;

  /**
   * Get the attached sub-menu for this item.
   * @return The sub-menu. <code>null</code> if it doesn't exist.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#method-getMenu Original Ext JS documentation of 'getMenu'
   */
  public native function getMenu():ext.menu.Menu;

  /**
   * @inheritDoc
   */
  public native function query(selector:String = null):Array;

  /**
   * @inheritDoc
   */
  public native function queryBy(fn:Function, scope:Object = null):Array;

  /**
   * @inheritDoc
   */
  public native function queryById(id:String):ext.Component;

  /**
   * Sets the value of <code>glyph</code>.
   * @param glyph The new value.
   * @see #glyph
   */
  public native function setGlyph(glyph:*):void;

  /**
   * Sets the <code>event:onClick</code> handler of this item
   * @param fn The handler function
   * @param scope The scope of the handler function
   * @see #event:onClick
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#method-setHandler Original Ext JS documentation of 'setHandler'
   */
  public native function setHandler(fn:Function, scope:Object = null):void;

  /**
   * Sets the <code>icon</code> on this item.
   * @param icon The new icon URL. If this <code>MenuItem</code> was configured with a <code>glyph</code>,
   * this may be a glyph configuration. See <code>glyph</code>.
   * @see #icon
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#method-setIcon Original Ext JS documentation of 'setIcon'
   * @see #glyph
   */
  public native function setIcon(icon:String):void;

  /**
   * Sets the <code>iconCls</code> of this item
   * @param iconCls The CSS class to set to <code>iconCls</code>
   * @see #iconCls
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#method-setIconCls Original Ext JS documentation of 'setIconCls'
   */
  public native function setIconCls(iconCls:String):void;

  /**
   * Set a child menu for this item. See the <code>menu</code> configuration.
   * @param menu A menu, or menu configuration. null may be
   * passed to remove the menu.
   * @param destroyMenu True to destroy any existing menu. False to
   * prevent destruction. If not specified, the <code>destroyMenu</code> configuration
   * will be used.
   * @see #menu
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#method-setMenu Original Ext JS documentation of 'setMenu'
   * @see #destroyMenu
   */
  public native function setMenu(menu:*, destroyMenu:Boolean = false):void;

  /**
   * Sets the <code>text</code> of this item
   * @param text The <code>text</code>
   * @see #text
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#method-setText Original Ext JS documentation of 'setText'
   */
  public native function setText(text:String):void;

  /**
   * Sets the tooltip for this menu item.
   * @param tooltip This may be:
   * <ul>
   * <li><b>String</b> : A string to be used as innerHTML (html tags are accepted) to show in a tooltip</li>
   * <li><b>Object</b> : A configuration object for <code>ext.tip.SQuickTipManager#register()</code>.</li>
   * </ul>
   * @return this
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Item.html#method-setTooltip Original Ext JS documentation of 'setTooltip'
   * @see ext.tip.SQuickTipManager#register()
   */
  public native function setTooltip(tooltip:*):ext.menu.Item;

  /**
   * @inheritDoc
   */
  public native function visitPostOrder(selector:Object, fn:Function, scope:Object = null, extraArgs:Array = null):void;

  /**
   * @inheritDoc
   */
  public native function visitPreOrder(selector:Object, fn:Function, scope:Object = null, extraArgs:Array = null):void;
}
}