package ext.mixin {
import ext.Base;
import ext.plugin.AbstractPlugin;

[Uses("ext.Base")]
[Native("Ext.mixin.Pluggable", require)]
/**
 * This mixin provides support for a <code>plugins</code> config and related API's.
 * <p>If this mixin is used for non-Components, the statements regarding the host being a
 * Component can be translated accordingly. The only requirement on the user of this class
 * is that the plugins actually used be appropriate for their host.</p>
 * <p>While <code>ext.Component</code> in the Classic Toolkit supports <code>plugins</code>, it does not use this
 * class to provide that support. This is due to backwards compatibility in regard to
 * timing changes this implementation would present.</p>
 * <p><b>Important:</b> To ensure plugins are destroyed, call <code>setPlugins(null)</code>.</p>
 * @see #plugins
 * @see ext.Component
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Pluggable.html Original Ext JS documentation of 'Ext.mixin.Pluggable'
 */
public class Pluggable extends ext.Base implements ext.mixin.IPluggable {
  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * An object or array of objects that will provide custom functionality for this
   * component. If a string is provided or a string is one of the elements of the
   * array, that string is treated as the <code>type</code> alias. For example, "listpaging"
   * is the type alias for <code>Ext.plugin.ListPaging</code>. The full alias includes the
   * "plugin." prefix (i.e., 'plugin.listpaging').
   * <p>Plugins should derive from <code>ext.plugin.AbstractPlugin</code> but this is not required. The
   * only requirement for a valid plugin is that it contain an <code>init()</code> method that
   * accepts a reference to the owning component.</p>
   * <p>When a component is created, if any plugins are available, the component will
   * call the <code>init</code> method on each plugin,
   * passing a reference to itself. Each plugin can then call methods or respond to
   * events on the component as needed to provide its functionality.</p>
   * <p><b><i>Example code</i></b></p>
   * <p>A plugin by alias:</p>
   * <pre>
   *  var list = Ext.create({
   *      xtype: 'list',
   *      itemTpl: '&lt;div class="item"&gt;{title}&lt;/div&gt;',
   *      store: 'Items',
   *
   *      plugins: 'listpaging'
   *  });
   * </pre>
   * <p>Multiple plugins by alias:</p>
   * <pre>
   *  var list = Ext.create({
   *      xtype: 'list',
   *      itemTpl: '&lt;div class="item"&gt;{title}&lt;/div&gt;',
   *      store: 'Items',
   *
   *      plugins: ['listpaging', 'pullrefresh']
   *  });
   * </pre>
   * <p>Single plugin by class name with config options:</p>
   * <pre>
   *  var list = Ext.create({
   *      xtype: 'list',
   *      itemTpl: '&lt;div class="item"&gt;{title}&lt;/div&gt;',
   *      store: 'Items',
   *
   *      plugins: {
   *          type: 'listpaging',
   *          autoPaging: true
   *      }
   *  });
   * </pre>
   * <p>Multiple plugins by type and class name with config options:</p>
   * <pre>
   *  var list = Ext.create({
   *      xtype: 'list',
   *      itemTpl: '&lt;div class="item"&gt;{title}&lt;/div&gt;',
   *      store: 'Items',
   *
   *      plugins: [{
   *          xclass: 'Ext.plugin.PullRefresh',
   *          pullRefreshText: 'Pull to refresh...'
   *      }, {
   *          type: 'listpaging',
   *          autoPaging: true
   *      }]
   *  });
   * </pre>
   * @see ext.plugin.AbstractPlugin
   * @see ext.plugin.AbstractPlugin#init()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Pluggable.html#cfg-plugins Original Ext JS documentation of 'plugins'
   * @see #getPlugins()
   * @see #setPlugins()
   */
  public native function get plugins():Array;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set plugins(value:Array):void;

  /**
   * Adds a plugin. For example:
   * <pre>
   *  list.addPlugin('pullrefresh');
   * </pre>
   * <p>Or:</p>
   * <pre>
   *  list.addPlugin({
   *      type: 'pullrefresh',
   *      pullRefreshText: 'Pull to refresh...'
   *  });
   * </pre>
   * @since 6.2.0
   * @param plugin The plugin or config object or
   * alias to add.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Pluggable.html#method-addPlugin Original Ext JS documentation of 'addPlugin'
   */
  public native function addPlugin(plugin:*):void;

  /**
   * Removes and destroys a plugin.
   * <p><b>Note:</b> Not all plugins are designed to be removable. Consult the documentation
   * for the specific plugin in question to be sure.</p>
   * @since 6.2.0
   * @param plugin The plugin or its <code>id</code> to remove.
   * @return plugin instance or <code>null</code> if not found.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Pluggable.html#method-destroyPlugin Original Ext JS documentation of 'destroyPlugin'
   */
  public native function destroyPlugin(plugin:*):ext.plugin.AbstractPlugin;

  /**
   * Retrieves plugin by its <code>type</code> alias. For example:
   * <pre>
   *  var list = Ext.create({
   *      xtype: 'list',
   *      itemTpl: '&lt;div class="item"&gt;{title}&lt;/div&gt;',
   *      store: 'Items',
   *
   *      plugins: ['listpaging', 'pullrefresh']
   *  });
   *
   *  list.findPlugin('pullrefresh').setPullRefreshText('Pull to refresh...');
   * </pre>
   * <p><b>Note:</b> See also <code>getPlugin()</code>.</p>
   * @since 6.2.0
   * @param type The Plugin's <code>type</code> as specified by the class's
   * <code>alias</code> configuration.
   * @return plugin instance or <code>null</code> if not found.
   * @see #getPlugin()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Pluggable.html#method-findPlugin Original Ext JS documentation of 'findPlugin'
   * @see ext.ExtClass#alias
   */
  public native function findPlugin(type:String):ext.plugin.AbstractPlugin;

  /**
   * Retrieves a plugin by its <code>id</code>.
   * <pre>
   *  var list = Ext.create({
   *      xtype: 'list',
   *      itemTpl: '&lt;div class="item"&gt;{title}&lt;/div&gt;',
   *      store: 'Items',
   *
   *      plugins: {
   *          xclass: 'Ext.plugin.PullRefresh',
   *          id: 'foo'
   *      }
   *  });
   *
   *  list.getPlugin('foo').setPullRefreshText('Pull to refresh...');
   * </pre>
   * <p><b>Note:</b> See also <code>findPlugin()</code>.</p>
   * @since 6.2.0
   * @param id The <code>id</code> of the plugin.
   * @return plugin instance or <code>null</code> if not found.
   * @see #findPlugin()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Pluggable.html#method-getPlugin Original Ext JS documentation of 'getPlugin'
   */
  public native function getPlugin(id:String):ext.plugin.AbstractPlugin;

  /**
   * Returns the value of <code>plugins</code>.
   * @see #plugins
   */
  public native function getPlugins():Array;

  /**
   * Removes and (optionally) destroys a plugin.
   * <p><b>Note:</b> Not all plugins are designed to be removable. Consult the documentation
   * for the specific plugin in question to be sure.</p>
   * @since 6.2.0
   * @param plugin The plugin or its <code>id</code> to remove.
   * @param destroy Pass <code>true</code> to not call <code>destroy()</code> on the plugin.
   * @return plugin instance or <code>null</code> if not found.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Pluggable.html#method-removePlugin Original Ext JS documentation of 'removePlugin'
   */
  public native function removePlugin(plugin:*, destroy:Boolean = false):ext.plugin.AbstractPlugin;

  /**
   * Sets the value of <code>plugins</code>.
   * @param plugins The new value.
   * @see #plugins
   */
  public native function setPlugins(plugins:Array):void;
}
}