package ext.picker {
import ext.Component;

[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.Base")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.Mixin")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Native("Ext.picker.Date", require)]
/**
 * @see ext.picker.events.DatePicker_dateEvent.SELECT
 * @eventType ext.picker.events.DatePicker_dateEvent.SELECT
 */
[Event(name = 'onSelect', type = 'ext.picker.events.DatePicker_dateEvent')]
/**
 * A date picker. This class is used by the Ext.form.field.Date field to allow browsing and selection of valid
 * dates in a popup next to the field, but may also be used with other components.
 * <p>Typically you will need to implement a handler function to be notified when the user chooses a date from the picker;
 * you can register the handler using the <code>event:onSelect</code> event, or by implementing the <code>handler</code> method.</p>
 * <p>By default the user will be allowed to pick any date; this can be changed by using the <code>minDate</code>,
 * <code>maxDate</code>, <code>disabledDays</code>, <code>disabledDatesRE</code>, and/or <code>disabledDates</code> configs.</p>
 * <p>All the string values documented below may be overridden by including an Ext locale file in your page.</p>
 * <p><b>Example:</b></p>
 * <pre>
 * Ext.create('Ext.panel.Panel', {
 *     title: 'Choose a future date:',
 *     width: 330,
 *     bodyPadding: 10,
 *     renderTo: Ext.getBody(),
 *     items: [{
 *         xtype: 'datepicker',
 *         minDate: new Date(),
 *         handler: function(picker, date) {
 *             // do something with the selected date
 *         }
 *     }]
 * });
 * </pre>
 * @see #event:onSelect
 * @see #handler
 * @see #minDate
 * @see #maxDate
 * @see #disabledDays
 * @see #disabledDatesRE
 * @see #disabledDates
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html Original Ext JS documentation of 'Ext.picker.Date'
 */
public class DatePicker extends ext.Component {
  /**
   * @param config @inheritDoc
   */
  public function DatePicker(config:ext.picker.DatePicker = null) {
    super();
  }

  [ExtConfig]
  /**
   * The text that Assistive Technologies such as screen readers
   * will announce when the date falls on a disabled date.
   * @default "This date is disabled"
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-ariaDisabledDatesText Original Ext JS documentation of 'ariaDisabledDatesText'
   */
  public native function get ariaDisabledDatesText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set ariaDisabledDatesText(value:String):void;

  [ExtConfig]
  /**
   * The text that Assistive Technologies such as screen readers
   * will announce when the date falls on a disabled day of week.
   * @default "This day of week is disabled"
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-ariaDisabledDaysText Original Ext JS documentation of 'ariaDisabledDaysText'
   */
  public native function get ariaDisabledDaysText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set ariaDisabledDaysText(value:String):void;

  [ExtConfig]
  /**
   * The text that will be announced by Assistive Technologies
   * such as screen readers when user is navigating to the cell which date is later than
   * <code>maxDate</code>.
   * @default "This date is after the maximum date"
   * @see #maxDate
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-ariaMaxText Original Ext JS documentation of 'ariaMaxText'
   */
  public native function get ariaMaxText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set ariaMaxText(value:String):void;

  [ExtConfig]
  /**
   * The text that will be announced by Assistive Technologies
   * such as screen readers when user is navigating to the cell which date is less than
   * <code>minDate</code>.
   * @default "This date is before the minimum date"
   * @see #minDate
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-ariaMinText Original Ext JS documentation of 'ariaMinText'
   */
  public native function get ariaMinText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set ariaMinText(value:String):void;

  [ExtConfig]
  /**
   * The text to display for the aria title
   * @default 'Date Picker: {0}'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-ariaTitle Original Ext JS documentation of 'ariaTitle'
   */
  public native function get ariaTitle():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set ariaTitle(value:String):void;

  [ExtConfig]
  /**
   * The date format to display for the current value in the <code>ariaTitle</code>
   * @default 'F d'
   * @see #ariaTitle
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-ariaTitleDateFormat Original Ext JS documentation of 'ariaTitleDateFormat'
   */
  public native function get ariaTitleDateFormat():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set ariaTitleDateFormat(value:String):void;

  [ExtConfig]
  /**
   * The base CSS class to apply to this components element.
   * @default 'x-datepicker'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-baseCls Original Ext JS documentation of 'baseCls'
   */
  override public native function get baseCls():String;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set baseCls(value:String):void;

  [ArrayElementType("String")]
  [Deprecated(replacement = "ext.SDateUtil")]
  [ExtConfig]
  /**
   * An array of textual day names which can be overriden for localization support (defaults to Ext.Date.dayNames)
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-dayNames Original Ext JS documentation of 'dayNames'
   */
  public native function get dayNames():Array;

  [ExtConfig]
  /**
   * @private
   */
  public native function set dayNames(value:Array):void;

  [ExtConfig]
  /**
   * True to disable animations when showing the month picker.
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-disableAnim Original Ext JS documentation of 'disableAnim'
   */
  public native function get disableAnim():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set disableAnim(value:Boolean):void;

  [ExtConfig]
  /**
   * The class to apply to disabled cells.
   * @default 'x-datepicker-disabled'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-disabledCellCls Original Ext JS documentation of 'disabledCellCls'
   */
  public native function get disabledCellCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set disabledCellCls(value:String):void;

  [ArrayElementType("String")]
  [ExtConfig]
  /**
   * An array of 'dates' to disable, as strings. These strings will be used to build a dynamic regular expression so
   * they are very powerful. Some examples:
   * <ul>
   * <li>['03/08/2003', '09/16/2003'] would disable those exact dates</li>
   * <li>['03/08', '09/16'] would disable those days for every year</li>
   * <li>['^03/08'] would only match the beginning (useful if you are using short years)</li>
   * <li>['03/../2006'] would disable every day in March 2006</li>
   * <li>['^03'] would disable every day in every March</li>
   * </ul>
   * <p>Note that the format of the dates included in the array should exactly match the <code>format</code> config. In order
   * to support regular expressions, if you are using a date format that has '.' in it, you will have to escape the
   * dot when restricting dates. For example: ['03\.08\.03'].</p>
   * @see #format
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-disabledDates Original Ext JS documentation of 'disabledDates'
   * @see #setDisabledDates()
   */
  public native function get disabledDates():Array;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set disabledDates(value:Array):void;

  [ExtConfig]
  /**
   * JavaScript regular expression used to disable a pattern of dates. The <code>disabledDates</code>
   * config will generate this regex internally, but if you specify disabledDatesRE it will take precedence over the
   * disabledDates value.
   * @see #disabledDates
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-disabledDatesRE Original Ext JS documentation of 'disabledDatesRE'
   */
  public native function get disabledDatesRE():RegExp;

  [ExtConfig]
  /**
   * @private
   */
  public native function set disabledDatesRE(value:RegExp):void;

  [ExtConfig]
  /**
   * The tooltip text to display when the date falls on a disabled date.
   * @default 'Disabled'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-disabledDatesText Original Ext JS documentation of 'disabledDatesText'
   */
  public native function get disabledDatesText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set disabledDatesText(value:String):void;

  [ArrayElementType("Number")]
  [ExtConfig]
  /**
   * An array of days to disable, 0-based. For example, [0, 6] disables Sunday and Saturday.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-disabledDays Original Ext JS documentation of 'disabledDays'
   * @see #setDisabledDays()
   */
  public native function get disabledDays():Array;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set disabledDays(value:Array):void;

  [ExtConfig]
  /**
   * The tooltip to display when the date falls on a disabled day.
   * @default 'Disabled'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-disabledDaysText Original Ext JS documentation of 'disabledDaysText'
   */
  public native function get disabledDaysText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set disabledDaysText(value:String):void;

  [ExtConfig]
  /**
   * The <code>ext.button.Button#ui</code> to use for the date picker's footer buttons.
   * @default 'default'
   * @see ext.button.Button#ui
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-footerButtonUI Original Ext JS documentation of 'footerButtonUI'
   */
  public native function get footerButtonUI():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set footerButtonUI(value:String):void;

  [ExtConfig]
  /**
   * The default date format string which can be overriden for localization support. The format must be valid
   * according to <code>ext.SDateUtil#parse()</code> (defaults to <code>ext.SDateUtil#defaultFormat</code>).
   * @see ext.SDateUtil#parse()
   * @see ext.SDateUtil#defaultFormat
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-format Original Ext JS documentation of 'format'
   */
  public native function get format():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set format(value:String):void;

  [ExtConfig]
  /**
   * Optional. A function that will handle the select event of this picker. The handler is passed the following
   * parameters:
   * <ul>
   * <li><code>picker</code> : Ext.picker.Date</li>
   * </ul>
   * <p>This Date picker.</p>
   * <ul>
   * <li><code>date</code> : Date</li>
   * </ul>
   * <p>The selected date.</p>
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-handler Original Ext JS documentation of 'handler'
   */
  public native function get handler():Function;

  [ExtConfig]
  /**
   * @private
   */
  public native function set handler(value:Function):void;

  [ExtConfig]
  /**
   * Specifies optional custom key event handlers for the <code>ext.util.KeyNav</code> attached to this date picker. Must
   * conform to the config format recognized by the <code>ext.util.KeyNav</code> constructor. Handlers specified in this
   * object will replace default handlers of the same name.
   * @see ext.util.KeyNav
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-keyNavConfig Original Ext JS documentation of 'keyNavConfig'
   */
  public native function get keyNavConfig():Object;

  [ExtConfig]
  /**
   * @private
   */
  public native function set keyNavConfig(value:Object):void;

  [ExtConfig]
  /**
   * The format for displaying a date in a longer format.
   * @default 'F d, Y'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-longDayFormat Original Ext JS documentation of 'longDayFormat'
   */
  public native function get longDayFormat():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set longDayFormat(value:String):void;

  [ExtConfig]
  /**
   * Maximum allowable date (JavaScript date object)
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-maxDate Original Ext JS documentation of 'maxDate'
   * @see #setMaxDate()
   */
  public native function get maxDate():Date;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set maxDate(value:Date):void;

  [ExtConfig]
  /**
   * The error text to display if the maxDate validation fails.
   * @default 'This date is after the maximum date'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-maxText Original Ext JS documentation of 'maxText'
   */
  public native function get maxText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set maxText(value:String):void;

  [ExtConfig]
  /**
   * Minimum allowable date (JavaScript date object)
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-minDate Original Ext JS documentation of 'minDate'
   * @see #setMinDate()
   */
  public native function get minDate():Date;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set minDate(value:Date):void;

  [ExtConfig]
  /**
   * The error text to display if the minDate validation fails.
   * @default 'This date is before the minimum date'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-minText Original Ext JS documentation of 'minText'
   */
  public native function get minText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set minText(value:String):void;

  [ArrayElementType("String")]
  [Deprecated(replacement = "ext.SDateUtil")]
  [ExtConfig]
  /**
   * An array of textual month names which can be overriden for localization support (defaults to Ext.Date.monthNames)
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-monthNames Original Ext JS documentation of 'monthNames'
   */
  public native function get monthNames():Array;

  [ExtConfig]
  /**
   * @private
   */
  public native function set monthNames(value:Array):void;

  [ExtConfig]
  /**
   * The date format for the header month
   * @default 'F Y'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-monthYearFormat Original Ext JS documentation of 'monthYearFormat'
   */
  public native function get monthYearFormat():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set monthYearFormat(value:String):void;

  [ExtConfig]
  /**
   * The header month selector tooltip
   * @default 'Choose a month (Control+Up/Down to move years)'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-monthYearText Original Ext JS documentation of 'monthYearText'
   */
  public native function get monthYearText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set monthYearText(value:String):void;

  [ExtConfig]
  /**
   * The next month navigation button tooltip
   * @default 'Next Month (Control+Right)'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-nextText Original Ext JS documentation of 'nextText'
   */
  public native function get nextText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set nextText(value:String):void;

  [ExtConfig]
  /**
   * The previous month navigation button tooltip
   * @default 'Previous Month (Control+Left)'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-prevText Original Ext JS documentation of 'prevText'
   */
  public native function get prevText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set prevText(value:String):void;

  [ExtConfig]
  /**
   * The scope (<code>this</code> reference) in which the <code>handler</code> function will be called.
   * <p>Defaults to this DatePicker instance.</p>
   * @see #handler
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-scope Original Ext JS documentation of 'scope'
   */
  public native function get scope():Object;

  [ExtConfig]
  /**
   * @private
   */
  public native function set scope(value:Object):void;

  [ExtConfig]
  /**
   * The class to apply to the selected cell.
   * @default 'x-datepicker-selected'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-selectedCls Original Ext JS documentation of 'selectedCls'
   */
  public native function get selectedCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set selectedCls(value:String):void;

  [ExtConfig]
  /**
   * False to hide the footer area containing the Today button and disable the keyboard handler for spacebar that
   * selects the current date.
   * @default true
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-showToday Original Ext JS documentation of 'showToday'
   */
  public native function get showToday():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set showToday(value:Boolean):void;

  [ExtConfig]
  /**
   * Day index at which the week should begin, 0-based.
   * <p>Defaults to <code>0</code> (Sunday).</p>
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-startDay Original Ext JS documentation of 'startDay'
   */
  public native function get startDay():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set startDay(value:Number):void;

  [ExtConfig]
  /**
   * The text to display on the button that selects the current date
   * @default 'Today'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-todayText Original Ext JS documentation of 'todayText'
   */
  public native function get todayText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set todayText(value:String):void;

  [ExtConfig]
  /**
   * A string used to format the message for displaying in a tooltip over the button that selects the current date.
   * The <code>{0}</code> token in string is replaced by today's date.
   * @default '{0} (Spacebar)'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#cfg-todayTip Original Ext JS documentation of 'todayTip'
   */
  public native function get todayTip():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set todayTip(value:String):void;

  /**
   * Gets a single character to represent the day of the week
   * @return The character
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#method-getDayInitial Original Ext JS documentation of 'getDayInitial'
   */
  public native function getDayInitial(value:*):String;

  /**
   * Gets the current selected value of the date field
   * @return The selected date
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#method-getValue Original Ext JS documentation of 'getValue'
   */
  public native function getValue():Date;

  /**
   * Hides the month picker, if it's visible.
   * @param animate Indicates whether to animate this action. If the animate
   * parameter is not specified, the behavior will use <code>disableAnim</code> to determine
   * whether to animate or not.
   * @return this
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#method-hideMonthPicker Original Ext JS documentation of 'hideMonthPicker'
   * @see #disableAnim
   */
  public native function hideMonthPicker(animate:Boolean = false):ext.picker.DatePicker;

  /**
   * Sets the current value to today.
   * @return this
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#method-selectToday Original Ext JS documentation of 'selectToday'
   */
  public native function selectToday():ext.picker.DatePicker;

  /**
   * Replaces any existing disabled dates with new values and refreshes the DatePicker.
   * @param disabledDates An array of date strings (see the <code>disabledDates</code> config for
   * details on supported values), or a JavaScript regular expression used to disable a pattern of dates.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#method-setDisabledDates Original Ext JS documentation of 'setDisabledDates'
   * @see #disabledDates
   */
  public native function setDisabledDates(disabledDates:*):void;

  /**
   * Replaces any existing disabled days (by index, 0-6) with new values and refreshes the DatePicker.
   * @param disabledDays An array of disabled day indexes. See the <code>disabledDays</code> config for details
   * on supported values.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#method-setDisabledDays Original Ext JS documentation of 'setDisabledDays'
   * @see #disabledDays
   */
  public native function setDisabledDays(disabledDays:Array):void;

  /**
   * Replaces any existing <code>maxDate</code> with the new value and refreshes the DatePicker.
   * @param value The maximum date that can be selected
   * @see #maxDate
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#method-setMaxDate Original Ext JS documentation of 'setMaxDate'
   */
  public native function setMaxDate(value:Date):void;

  /**
   * Replaces any existing <code>minDate</code> with the new value and refreshes the DatePicker.
   * @param value The minimum date that can be selected
   * @see #minDate
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#method-setMinDate Original Ext JS documentation of 'setMinDate'
   */
  public native function setMinDate(value:Date):void;

  /**
   * Sets the value of the date field
   * @param value The date to set
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#method-setValue Original Ext JS documentation of 'setValue'
   */
  public native function setValue(value:Date):void;

  /**
   * Show the month picker
   * @param animate Indicates whether to animate this action. If the animate
   * parameter is not specified, the behavior will use <code>disableAnim</code> to determine
   * whether to animate or not.
   * @return this
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#method-showMonthPicker Original Ext JS documentation of 'showMonthPicker'
   * @see #disableAnim
   */
  public native function showMonthPicker(animate:Boolean = false):ext.picker.DatePicker;

  /**
   * Show the next month.
   * @return this
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#method-showNextMonth Original Ext JS documentation of 'showNextMonth'
   */
  public native function showNextMonth(e:Object):ext.picker.DatePicker;

  /**
   * Show the next year.
   * @return this
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#method-showNextYear Original Ext JS documentation of 'showNextYear'
   */
  public native function showNextYear():ext.picker.DatePicker;

  /**
   * Show the previous month.
   * @return this
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#method-showPrevMonth Original Ext JS documentation of 'showPrevMonth'
   */
  public native function showPrevMonth(e:Object):ext.picker.DatePicker;

  /**
   * Show the previous year.
   * @return this
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Date.html#method-showPrevYear Original Ext JS documentation of 'showPrevYear'
   */
  public native function showPrevYear():ext.picker.DatePicker;
}
}