package ext.selection {
import ext.grid.column.Column;

[Uses("ext.selection.RowSelectionModel")]
[Uses("ext.selection.DataViewSelectionModel")]
[Uses("ext.selection.SelectionModel")]
[Uses("ext.mixin.Factoryable")]
[Uses("ext.Base")]
[Uses("ext.util.StoreHolder")]
[Uses("ext.mixin.Observable")]
[Uses("ext.Mixin")]
[Uses("ext.mixin.Identifiable")]
[Native("Ext.selection.CheckboxModel", require)]
/**
 * A selection model that renders a column of checkboxes that can be toggled to
 * select or deselect rows. The default mode for this selection model is MULTI.
 * <p><b>Example:</b></p>
 * <pre>
 *   var store = Ext.create('Ext.data.Store', {
 *       fields: ['name', 'email', 'phone'],
 *       data: [{
 *           name: 'Lisa',
 *           email: 'lisa&#64;simpsons.com',
 *           phone: '555-111-1224'
 *       }, {
 *           name: 'Bart',
 *           email: 'bart&#64;simpsons.com',
 *           phone: '555-222-1234'
 *       }, {
 *           name: 'Homer',
 *           email: 'homer&#64;simpsons.com',
 *           phone: '555-222-1244'
 *       }, {
 *           name: 'Marge',
 *           email: 'marge&#64;simpsons.com',
 *           phone: '555-222-1254'
 *       }]
 *   });
 *
 *   Ext.create('Ext.grid.Panel', {
 *       title: 'Simpsons',
 *       store: store,
 *       columns: [{
 *           text: 'Name',
 *           dataIndex: 'name'
 *       }, {
 *           text: 'Email',
 *           dataIndex: 'email',
 *           flex: 1
 *       }, {
 *           text: 'Phone',
 *           dataIndex: 'phone'
 *       }],
 *       height: 200,
 *       width: 400,
 *       renderTo: Ext.getBody(),
 *       selModel: {
 *           selType: 'checkboxmodel'
 *       }
 *   });
 * </pre>
 * <p>The selection model will inject a header for the checkboxes in the first view
 * and according to the <code>injectCheckbox</code> configuration.</p>
 * @see #injectCheckbox
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.selection.CheckboxModel.html Original Ext JS documentation of 'Ext.selection.CheckboxModel'
 */
public class CheckboxSelectionModel extends ext.selection.RowSelectionModel {
  /**
   * @param config @inheritDoc
   */
  public function CheckboxSelectionModel(config:ext.selection.CheckboxSelectionModel = null) {
    super();
  }

  [ExtConfig]
  /**
   * True if rows can only be selected by clicking on the checkbox column, not by clicking
   * on the row itself. Note that this only refers to selection via the UI, programmatic
   * selection will still occur regardless.
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.selection.CheckboxModel.html#cfg-checkOnly Original Ext JS documentation of 'checkOnly'
   */
  public native function get checkOnly():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set checkOnly(value:Boolean):void;

  [ExtConfig]
  /**
   * ARIA label for screen readers to announce for the check column's header when it is focused.
   * Note that this label will not be visible on screen.
   * @default "Row selector"
   * @since 6.2.0
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.selection.CheckboxModel.html#cfg-headerAriaLabel Original Ext JS documentation of 'headerAriaLabel'
   */
  public native function get headerAriaLabel():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set headerAriaLabel(value:String):void;

  [ExtConfig]
  /**
   * ARIA description text to announce for the check column's header when it is focused,
   * <code>showHeaderCheckbox</code> is shown, and all rows are selected.
   * @default "Press Space to deselect all rows"
   * @see #showHeaderCheckbox
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.selection.CheckboxModel.html#cfg-headerDeselectText Original Ext JS documentation of 'headerDeselectText'
   */
  public native function get headerDeselectText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set headerDeselectText(value:String):void;

  [ExtConfig]
  /**
   * ARIA description text to announce for the check column's header when it is focused,
   * <code>showHeaderCheckbox</code> is shown, and not all rows are selected.
   * @default "Press Space to select all rows"
   * @since 6.2.0
   * @see #showHeaderCheckbox
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.selection.CheckboxModel.html#cfg-headerSelectText Original Ext JS documentation of 'headerSelectText'
   */
  public native function get headerSelectText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set headerSelectText(value:String):void;

  [ExtConfig]
  /**
   * Displays the configured text in the check column's header.
   * <p>if <code>showHeaderCheckbox</code> is <code>true</code>, the text is shown <i>above</i> the checkbox.</p>
   * @since 6.0.1
   * @see #showHeaderCheckbox
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.selection.CheckboxModel.html#cfg-headerText Original Ext JS documentation of 'headerText'
   */
  public native function get headerText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set headerText(value:String):void;

  [ExtConfig]
  /**
   * The index at which to insert the checkbox column.
   * Supported values are a numeric index, and the strings 'first' and 'last'.
   * @default 0
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.selection.CheckboxModel.html#cfg-injectCheckbox Original Ext JS documentation of 'injectCheckbox'
   */
  public native function get injectCheckbox():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set injectCheckbox(value:*):void;

  [ExtConfig]
  /**
   * Modes of selection.
   * Valid values are <code>"SINGLE"</code>, <code>"SIMPLE"</code>, and <code>"MULTI"</code>.
   * @default 'MULTI'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.selection.CheckboxModel.html#cfg-mode Original Ext JS documentation of 'mode'
   */
  override public native function get mode():String;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set mode(value:String):void;

  [ExtConfig]
  /**
   * ARIA description text to announce when check column cell is focused and the row
   * is selected.
   * @default "Press Space to deselect this row"
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.selection.CheckboxModel.html#cfg-rowDeselectText Original Ext JS documentation of 'rowDeselectText'
   */
  public native function get rowDeselectText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set rowDeselectText(value:String):void;

  [ExtConfig]
  /**
   * ARIA description text to announce when check column cell is focused and the row
   * is not selected.
   * @default "Press Space to select this row"
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.selection.CheckboxModel.html#cfg-rowSelectText Original Ext JS documentation of 'rowSelectText'
   */
  public native function get rowSelectText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set rowSelectText(value:String):void;

  [ExtConfig]
  /**
   * Configure as <code>false</code> to not display the header checkbox at the top of the column.
   * When the store is a <code>ext.data.BufferedStore</code>, this configuration will
   * not be available because the buffered data set does not always contain all data.
   * @default false
   * @see ext.data.BufferedStore
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.selection.CheckboxModel.html#cfg-showHeaderCheckbox Original Ext JS documentation of 'showHeaderCheckbox'
   */
  public native function get showHeaderCheckbox():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set showHeaderCheckbox(value:Boolean):void;

  /**
   * Retrieve a configuration to be used in a HeaderContainer.
   * This is called when injectCheckbox is not <code>false</code>.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.selection.CheckboxModel.html#method-getHeaderConfig Original Ext JS documentation of 'getHeaderConfig'
   */
  public native function getHeaderConfig():ext.grid.column.Column;

  /**
   * Toggle between selecting all and deselecting all when clicking on
   * a checkbox header.
   */
  override protected native function onHeaderClick():void;
}
}