package ext.view {
import ext.data.Store;
import ext.panel.Panel;

[Uses("ext.panel.Panel")]
[Uses("ext.container.DockingContainer")]
[Uses("ext.Base")]
[Uses("ext.container.Container")]
[Uses("ext.mixin.Queryable")]
[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.Mixin")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Uses("ext.mixin.Container")]
[Native("Ext.view.MultiSelectorSearch", require)]
/**
 * This component provides a grid holding selected items from a second store of potential
 * members. The <code>store</code> of this component represents the selected items. The <code>searchStore</code>
 * represents the potentially selected items.
 * <p>The default view defined by this class is intended to be easily replaced by deriving a
 * new class and overriding the appropriate methods. For example, the following is a very
 * different view that uses a date range and a data view:</p>
 * <pre>
 *  Ext.define('App.view.DateBoundSearch', {
 *      extend: 'Ext.view.MultiSelectorSearch',
 *
 *      makeDockedItems: function () {
 *          return {
 *              xtype: 'toolbar',
 *              items: [{
 *                  xtype: 'datefield',
 *                  emptyText: 'Start date...',
 *                  flex: 1
 *              },{
 *                  xtype: 'datefield',
 *                  emptyText: 'End date...',
 *                  flex: 1
 *              }]
 *          };
 *      },
 *
 *      makeItems: function () {
 *          return [{
 *              xtype: 'dataview',
 *              itemSelector: '.search-item',
 *              selModel: 'rowselection',
 *              store: this.store,
 *              scrollable: true,
 *              tpl:
 *                  '&lt;tpl for="."&gt;' +
 *                      '&lt;div class="search-item"&gt;' +
 *                          '&lt;img src="{icon}"&gt;' +
 *                          '&lt;div&gt;{name}&lt;/div&gt;' +
 *                      '&lt;/div&gt;' +
 *                  '&lt;/tpl&gt;'
 *          }];
 *      },
 *
 *      getSearchStore: function () {
 *          return this.items.getAt(0).getStore();
 *      },
 *
 *      selectRecords: function (records) {
 *          var view = this.items.getAt(0);
 *          return view.getSelectionModel().select(records);
 *      }
 *  });
 * </pre>
 * <p><b>Important</b>: This class assumes there are two components with specific <code>reference</code>
 * names assigned to them. These are <code>"searchField"</code> and <code>"searchGrid"</code>. These components
 * are produced by the <code>makeDockedItems</code> and <code>makeItems</code> method, respectively. When
 * overriding these it is important to remember to place these <code>reference</code> values on the
 * appropriate components.</p>
 * @see #store
 * @see #reference
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.view.MultiSelectorSearch.html Original Ext JS documentation of 'Ext.view.MultiSelectorSearch'
 */
public class MultiSelectorSearchView extends ext.panel.Panel {
  /**
   * @param config @inheritDoc
   */
  public function MultiSelectorSearchView(config:ext.view.MultiSelectorSearchView = null) {
    super();
  }

  [ExtConfig]
  /**
   * A field from your grid's store that will be used for filtering your search results.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.view.MultiSelectorSearch.html#cfg-field Original Ext JS documentation of 'field'
   */
  public native function get field():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set field(value:String):void;

  [ExtConfig]
  /**
   * This text is displayed as the "emptyText" of the search <code>textfield</code>.
   * @default 'Search...'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.view.MultiSelectorSearch.html#cfg-searchText Original Ext JS documentation of 'searchText'
   */
  public native function get searchText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set searchText(value:String):void;

  [ExtConfig]
  /**
   * The data source to which the grid / tree is bound. Acceptable values for this
   * property are:
   * <ul>
   * <li><b>any <code>ext.data.Store</code> class / subclass</b></li>
   * <li><b>an <i>ID of a store</i></b></li>
   * <li><b>a <code>ext.data.Store</code> config object</b>. When passing a config you can
   * specify the store type by alias. Passing a config object with a store type will
   * dynamically create a new store of that type when the grid / tree is instantiated.</li>
   * </ul>
   * <p>For example:</p>
   * <pre>
   * Ext.define('MyApp.store.Customers', {
   *     extend: 'Ext.data.Store',
   *     alias: 'store.customerstore',
   *     fields: ['name']
   * });
   *
   * Ext.create({
   *     xtype: 'gridpanel',
   *     renderTo: document.body,
   *     store: {
   *         type: 'customerstore',
   *         data: [{
   *             name: 'Foo'
   *         }]
   *     },
   *     columns: [{
   *         text: 'Name',
   *         dataIndex: 'name'
   *     }]
   * });
   * </pre>
   * @see ext.data.Store
   * @see ext.data.Store#storeId ID of a store
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.view.MultiSelectorSearch.html#cfg-store Original Ext JS documentation of 'store'
   */
  public native function get store():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set store(value:*):void;

  /**
   * Returns the store that holds search results. By default this comes from the
   * "search grid". If this aspect of the view is changed sufficiently so that the
   * search grid cannot be found, this method should be overridden to return the proper
   * store.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.view.MultiSelectorSearch.html#method-getSearchStore Original Ext JS documentation of 'getSearchStore'
   */
  public native function getSearchStore():ext.data.Store;
}
}